import{c as B,r as j,j as s,u as pe,e as le}from"./index-qMrAuFFG.js";import{Y as c,Z as v,$ as ie,a0 as Lt,a1 as $e,a2 as Rt,a3 as Jt,a4 as Ft,a5 as Mt,a6 as Kt,a7 as Gt,a8 as Wt,a9 as Bt,aa as Xt,ab as Vt,ac as qt,ad as Yt,ae as Ht,af as Qt,ag as er,ah as tr,ai as rr,aj as nr,ak as ir,al as ar,am as or,an as ur,ao as lr,ap as cr,aq as sr,ar as dr,as as mr,at as fr,au as gr,av as vr,aw as pr,ax as $r,ay as br,az as yr,aA as hr,aB as _r,aC as kr,aD as Ir,aE as Sr,aF as jr,aG as xr,aH as Ur,aI as Or,aJ as wr,aK as Nr,aL as zr,aM as Dr,aN as Pr,aO as Tr,aP as Er,aQ as Ar,aR as Zr,aS as Cr,aT as Lr,aU as Rr,aV as Jr,aW as Fr,aX as Mr,aY as Kr,aZ as Gr,a_ as Wr,a$ as Br,b0 as Xr,b1 as Vr,b2 as qr,b3 as Yr,b4 as Hr,b5 as Qr,b6 as en,b7 as tn,b8 as rn,b9 as nn,ba as an,bb as on,bc as un,bd as ln,be as cn,bf as sn,bg as dn,bh as mn,bi as fn,bj as gn,bk as vn,bl as pn,bm as $n,bn,bo as yn,bp as hn,bq as _n,br as kn,bs as In,bt as Sn,bu as jn,bv as xn,bw as Un,bx as On,by as be,bz as wn,bA as ye,bB as he,bC as Nn,bD as _e,bE as ke,bF as zn,bG as Dn,bH as Pn,bI as Tn,bJ as En,bK as An,bL as Zn,bM as Cn,bN as Ln,bO as Rn,bP as Ie,bQ as Se,bR as je,bS as xe,bT as Ue,bU as Jn,bV as Fn,bW as Mn,bX as Kn,bY as Gn,bZ as Wn,b_ as Bn,b$ as Xn,c0 as Vn,c1 as qn,c2 as Yn,c3 as Hn,c4 as Qn,c5 as Oe,c6 as ei,c7 as ti,c8 as ri,c9 as ni,ca as we,cb as ee,cc as ii,cd as Ne,ce as ai,cf as oi,cg as ui,ch as li,ci,cj as si,ck as di,cl as mi,cm as fi,cn as gi,co as vi,cp as pi,cq as $i,cr as ze,cs as bi,ct as De,cu as Pe,cv as te,cw as yi,cx as Te,cy as Ee,cz as Ae,cA as Ze,cB as Ce,cC as Le,cD as hi,cE as _i,cF as ki,cG as Re,cH as Ii,cI as Je,cJ as Si,cK as Fe,cL as Me,cM as ji,cN as xi,cO as Ui,cP as Oi,cQ as Ke,cR as wi,cS as Ni,cT as zi,cU as Ge,cV as Di,cW as We,cX as Pi,cY as Ti,cZ as Ei,c_ as Be,c$ as Ai,d0 as Zi,d1 as Ci,d2 as Li,d3 as Ri,d4 as Ji,d5 as Fi,d6 as Xe,d7 as Ve,d8 as Mi,d9 as Ki,da as Gi,db as Wi,dc as Bi,dd as Xi,de as Vi,df as qe,dg as Ye,dh as qi,di as He,dj as Yi,dk as Hi,dl as Qi,dm as ea,dn as ta,dp as ra,dq as na,dr as Qe,ds as ia,dt as aa,du as oa,dv as ua,dw as la,dx as ca,dy as sa,dz as et,dA as ae,dB as da,dC as ma,dD as fa,dE as ga,dF as tt,dG as rt,dH as va,dI as pa,dJ as $a,dK as ba,dL as ya,dM as ha,dN as nt,dO as it,dP as at,dQ as _a,dR as ka,dS as Ia,dT as Sa,dU as ja,dV as xa,dW as Ua,dX as ot,dY as ut,dZ as Oa,d_ as lt,d$ as ct,e0 as st,e1 as dt,e2 as mt,e3 as wa,e4 as Na,e5 as za,e6 as Da,e7 as Pa,e8 as Ta,e9 as Ea,ea as Aa,eb as Za,ec as Ca,ed as La,ee as Ra,ef as Ja,eg as Fa,eh as Ma,ei as Ka,ej as Ga,ek as Wa,el as Ba,em as Xa,en as Va,eo as qa,ep as Ya,eq as Ha,er as Qa,es as eo,et as to,eu as ro,ev as no,ew as io,ex as ao,ey as oo,ez as uo,eA as lo,eB as co,eC as so,eD as mo,eE as fo,eF as go,eG as vo,eH as po,eI as $o,eJ as bo,eK as yo,eL as ho,eM as _o,eN as ko,eO as Io,eP as So,eQ as jo,eR as xo,eS as Uo,eT as Oo,eU as wo,eV as No,eW as zo,eX as Do,eY as Po,eZ as To,e_ as Eo,e$ as Ao,f0 as Zo,f1 as Co,f2 as Lo,f3 as Ro,f4 as Jo,f5 as Fo,f6 as Mo,f7 as Ko,f8 as Go,f9 as ce,fa as P,Q as L,fb as Wo,fc as Bo,fd as Xo,O as D,fe as Vo,ff as qo,fg as Yo,fh as Ho,fi as Qo,fj as eu,fk as tu,fl as ru,fm as ft,fn as nu,fo as iu,U as au,fp as ou,fq as uu,fr as lu,fs as cu,ft as su,_ as F,fu as du,fv as mu,fw as fu,fx as gu,fy as vu,fz as pu,fA as $u,fB as bu,fC as yu,fD as hu,fE as _u,fF as ku,fG as Iu,fH as Su,fI as ju,fJ as xu,fK as Uu,fL as Ou,fM as wu,fN as Nu,fO as zu,fP as Du,fQ as Pu,fR as Tu,fS as Eu,fT as Au,fU as Zu,fV as Cu,fW as Lu,fX as Ru,fY as Ju,fZ as U,f_ as Fu,N as h,K as k,f$ as Mu,g0 as Ku,g1 as Gu,g2 as Wu,g3 as Bu,g4 as Xu,g5 as Vu,g6 as qu,g7 as Yu,M as C,g8 as Hu,g9 as Qu,ga as el,gb as tl,gc as rl,gd as nl,ge as il,gf as al,gg as ol,gh as ul,T as $,gi as ll,gj as cl,gk as sl,gl as dl,gm as ml,gn as fl,go as gl,gp as vl,gq as pl,gr as $l,gs as bl,gt as yl,gu as hl,gv as _l,gw as kl,gx as Il,gy as Sl,gz as jl,gA as xl,gB as Ul,gC as Ol,i as gt,E as wl,R as Nl,g as zl,G as Dl,n as vt,r as pt,o as W,A as $t,l as bt,m as Pl,p as Tl,v as El,w as Al,t as Zl,F as Cl,D as Ll,C as Rl,y as Jl,B as Fl,f as Ml,e as Kl}from"./loading-PETOxw4W.js";import{c as R,C as yt}from"./queries-B0q6a4VE.js";import{A as Gl}from"./alert-message-DBiN770l.js";import{R as ht}from"./refresh-cw-BtfCr9OP.js";import{C as Wl,a as Bl}from"./clock-Dmcvs345.js";/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Xl=[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["path",{d:"m4.9 4.9 14.2 14.2",key:"1m5liu"}]],Vl=B("Ban",Xl);/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ql=[["rect",{width:"7",height:"7",x:"14",y:"3",rx:"1",key:"6d4xhi"}],["path",{d:"M10 21V8a1 1 0 0 0-1-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-5a1 1 0 0 0-1-1H3",key:"1fpvtg"}]],Yl=B("Blocks",ql);/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Hl=[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["circle",{cx:"12",cy:"12",r:"1",key:"41hilf"}]],Ql=B("CircleDot",Hl);/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ec=[["path",{d:"M12 6v6l4 2",key:"mmk7yg"}],["path",{d:"M16 21.16a10 10 0 1 1 5-13.516",key:"cxo92l"}],["path",{d:"M20 11.5v6",key:"2ei3xq"}],["path",{d:"M20 21.5h.01",key:"1r2dzp"}]],tc=B("ClockAlert",ec);/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const rc=[["path",{d:"M12 22v-9",key:"x3hkom"}],["path",{d:"M15.17 2.21a1.67 1.67 0 0 1 1.63 0L21 4.57a1.93 1.93 0 0 1 0 3.36L8.82 14.79a1.655 1.655 0 0 1-1.64 0L3 12.43a1.93 1.93 0 0 1 0-3.36z",key:"2ntwy6"}],["path",{d:"M20 13v3.87a2.06 2.06 0 0 1-1.11 1.83l-6 3.08a1.93 1.93 0 0 1-1.78 0l-6-3.08A2.06 2.06 0 0 1 4 16.87V13",key:"1pmm1c"}],["path",{d:"M21 12.43a1.93 1.93 0 0 0 0-3.36L8.83 2.2a1.64 1.64 0 0 0-1.63 0L3 4.57a1.93 1.93 0 0 0 0 3.36l12.18 6.86a1.636 1.636 0 0 0 1.63 0z",key:"12ttoo"}]],Td=B("PackageOpen",rc),nc=()=>{const a={string:{unit:"حرف",verb:"أن يحوي"},file:{unit:"بايت",verb:"أن يحوي"},array:{unit:"عنصر",verb:"أن يحوي"},set:{unit:"عنصر",verb:"أن يحوي"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"number";case"object":{if(Array.isArray(e))return"array";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"مدخل",email:"بريد إلكتروني",url:"رابط",emoji:"إيموجي",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"تاريخ ووقت بمعيار ISO",date:"تاريخ بمعيار ISO",time:"وقت بمعيار ISO",duration:"مدة بمعيار ISO",ipv4:"عنوان IPv4",ipv6:"عنوان IPv6",cidrv4:"مدى عناوين بصيغة IPv4",cidrv6:"مدى عناوين بصيغة IPv6",base64:"نَص بترميز base64-encoded",base64url:"نَص بترميز base64url-encoded",json_string:"نَص على هيئة JSON",e164:"رقم هاتف بمعيار E.164",jwt:"JWT",template_literal:"مدخل"};return e=>{switch(e.code){case"invalid_type":return`مدخلات غير مقبولة: يفترض إدخال ${e.expected}، ولكن تم إدخال ${o(e.input)}`;case"invalid_value":return e.values.length===1?`مدخلات غير مقبولة: يفترض إدخال ${v(e.values[0])}`:`اختيار غير مقبول: يتوقع انتقاء أحد هذه الخيارات: ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?` أكبر من اللازم: يفترض أن تكون ${e.origin??"القيمة"} ${t} ${e.maximum.toString()} ${r.unit??"عنصر"}`:`أكبر من اللازم: يفترض أن تكون ${e.origin??"القيمة"} ${t} ${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`أصغر من اللازم: يفترض لـ ${e.origin} أن يكون ${t} ${e.minimum.toString()} ${r.unit}`:`أصغر من اللازم: يفترض لـ ${e.origin} أن يكون ${t} ${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`نَص غير مقبول: يجب أن يبدأ بـ "${e.prefix}"`:t.format==="ends_with"?`نَص غير مقبول: يجب أن ينتهي بـ "${t.suffix}"`:t.format==="includes"?`نَص غير مقبول: يجب أن يتضمَّن "${t.includes}"`:t.format==="regex"?`نَص غير مقبول: يجب أن يطابق النمط ${t.pattern}`:`${n[t.format]??e.format} غير مقبول`}case"not_multiple_of":return`رقم غير مقبول: يجب أن يكون من مضاعفات ${e.divisor}`;case"unrecognized_keys":return`معرف${e.keys.length>1?"ات":""} غريب${e.keys.length>1?"ة":""}: ${c(e.keys,"، ")}`;case"invalid_key":return`معرف غير مقبول في ${e.origin}`;case"invalid_union":return"مدخل غير مقبول";case"invalid_element":return`مدخل غير مقبول في ${e.origin}`;default:return"مدخل غير مقبول"}}};function ic(){return{localeError:nc()}}const ac=()=>{const a={string:{unit:"simvol",verb:"olmalıdır"},file:{unit:"bayt",verb:"olmalıdır"},array:{unit:"element",verb:"olmalıdır"},set:{unit:"element",verb:"olmalıdır"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"number";case"object":{if(Array.isArray(e))return"array";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"input",email:"email address",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO datetime",date:"ISO date",time:"ISO time",duration:"ISO duration",ipv4:"IPv4 address",ipv6:"IPv6 address",cidrv4:"IPv4 range",cidrv6:"IPv6 range",base64:"base64-encoded string",base64url:"base64url-encoded string",json_string:"JSON string",e164:"E.164 number",jwt:"JWT",template_literal:"input"};return e=>{switch(e.code){case"invalid_type":return`Yanlış dəyər: gözlənilən ${e.expected}, daxil olan ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Yanlış dəyər: gözlənilən ${v(e.values[0])}`:`Yanlış seçim: aşağıdakılardan biri olmalıdır: ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Çox böyük: gözlənilən ${e.origin??"dəyər"} ${t}${e.maximum.toString()} ${r.unit??"element"}`:`Çox böyük: gözlənilən ${e.origin??"dəyər"} ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Çox kiçik: gözlənilən ${e.origin} ${t}${e.minimum.toString()} ${r.unit}`:`Çox kiçik: gözlənilən ${e.origin} ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Yanlış mətn: "${t.prefix}" ilə başlamalıdır`:t.format==="ends_with"?`Yanlış mətn: "${t.suffix}" ilə bitməlidir`:t.format==="includes"?`Yanlış mətn: "${t.includes}" daxil olmalıdır`:t.format==="regex"?`Yanlış mətn: ${t.pattern} şablonuna uyğun olmalıdır`:`Yanlış ${n[t.format]??e.format}`}case"not_multiple_of":return`Yanlış ədəd: ${e.divisor} ilə bölünə bilən olmalıdır`;case"unrecognized_keys":return`Tanınmayan açar${e.keys.length>1?"lar":""}: ${c(e.keys,", ")}`;case"invalid_key":return`${e.origin} daxilində yanlış açar`;case"invalid_union":return"Yanlış dəyər";case"invalid_element":return`${e.origin} daxilində yanlış dəyər`;default:return"Yanlış dəyər"}}};function oc(){return{localeError:ac()}}function se(a,i,o,n){const e=Math.abs(a),t=e%10,r=e%100;return r>=11&&r<=19?n:t===1?i:t>=2&&t<=4?o:n}const uc=()=>{const a={string:{unit:{one:"сімвал",few:"сімвалы",many:"сімвалаў"},verb:"мець"},array:{unit:{one:"элемент",few:"элементы",many:"элементаў"},verb:"мець"},set:{unit:{one:"элемент",few:"элементы",many:"элементаў"},verb:"мець"},file:{unit:{one:"байт",few:"байты",many:"байтаў"},verb:"мець"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"лік";case"object":{if(Array.isArray(e))return"масіў";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"увод",email:"email адрас",url:"URL",emoji:"эмодзі",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO дата і час",date:"ISO дата",time:"ISO час",duration:"ISO працягласць",ipv4:"IPv4 адрас",ipv6:"IPv6 адрас",cidrv4:"IPv4 дыяпазон",cidrv6:"IPv6 дыяпазон",base64:"радок у фармаце base64",base64url:"радок у фармаце base64url",json_string:"JSON радок",e164:"нумар E.164",jwt:"JWT",template_literal:"увод"};return e=>{switch(e.code){case"invalid_type":return`Няправільны ўвод: чакаўся ${e.expected}, атрымана ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Няправільны ўвод: чакалася ${v(e.values[0])}`:`Няправільны варыянт: чакаўся адзін з ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);if(r){const u=Number(e.maximum),d=se(u,r.unit.one,r.unit.few,r.unit.many);return`Занадта вялікі: чакалася, што ${e.origin??"значэнне"} павінна ${r.verb} ${t}${e.maximum.toString()} ${d}`}return`Занадта вялікі: чакалася, што ${e.origin??"значэнне"} павінна быць ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);if(r){const u=Number(e.minimum),d=se(u,r.unit.one,r.unit.few,r.unit.many);return`Занадта малы: чакалася, што ${e.origin} павінна ${r.verb} ${t}${e.minimum.toString()} ${d}`}return`Занадта малы: чакалася, што ${e.origin} павінна быць ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Няправільны радок: павінен пачынацца з "${t.prefix}"`:t.format==="ends_with"?`Няправільны радок: павінен заканчвацца на "${t.suffix}"`:t.format==="includes"?`Няправільны радок: павінен змяшчаць "${t.includes}"`:t.format==="regex"?`Няправільны радок: павінен адпавядаць шаблону ${t.pattern}`:`Няправільны ${n[t.format]??e.format}`}case"not_multiple_of":return`Няправільны лік: павінен быць кратным ${e.divisor}`;case"unrecognized_keys":return`Нераспазнаны ${e.keys.length>1?"ключы":"ключ"}: ${c(e.keys,", ")}`;case"invalid_key":return`Няправільны ключ у ${e.origin}`;case"invalid_union":return"Няправільны ўвод";case"invalid_element":return`Няправільнае значэнне ў ${e.origin}`;default:return"Няправільны ўвод"}}};function lc(){return{localeError:uc()}}const cc=a=>{const i=typeof a;switch(i){case"number":return Number.isNaN(a)?"NaN":"число";case"object":{if(Array.isArray(a))return"масив";if(a===null)return"null";if(Object.getPrototypeOf(a)!==Object.prototype&&a.constructor)return a.constructor.name}}return i},sc=()=>{const a={string:{unit:"символа",verb:"да съдържа"},file:{unit:"байта",verb:"да съдържа"},array:{unit:"елемента",verb:"да съдържа"},set:{unit:"елемента",verb:"да съдържа"}};function i(n){return a[n]??null}const o={regex:"вход",email:"имейл адрес",url:"URL",emoji:"емоджи",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO време",date:"ISO дата",time:"ISO време",duration:"ISO продължителност",ipv4:"IPv4 адрес",ipv6:"IPv6 адрес",cidrv4:"IPv4 диапазон",cidrv6:"IPv6 диапазон",base64:"base64-кодиран низ",base64url:"base64url-кодиран низ",json_string:"JSON низ",e164:"E.164 номер",jwt:"JWT",template_literal:"вход"};return n=>{switch(n.code){case"invalid_type":return`Невалиден вход: очакван ${n.expected}, получен ${cc(n.input)}`;case"invalid_value":return n.values.length===1?`Невалиден вход: очакван ${v(n.values[0])}`:`Невалидна опция: очаквано едно от ${c(n.values,"|")}`;case"too_big":{const e=n.inclusive?"<=":"<",t=i(n.origin);return t?`Твърде голямо: очаква се ${n.origin??"стойност"} да съдържа ${e}${n.maximum.toString()} ${t.unit??"елемента"}`:`Твърде голямо: очаква се ${n.origin??"стойност"} да бъде ${e}${n.maximum.toString()}`}case"too_small":{const e=n.inclusive?">=":">",t=i(n.origin);return t?`Твърде малко: очаква се ${n.origin} да съдържа ${e}${n.minimum.toString()} ${t.unit}`:`Твърде малко: очаква се ${n.origin} да бъде ${e}${n.minimum.toString()}`}case"invalid_format":{const e=n;if(e.format==="starts_with")return`Невалиден низ: трябва да започва с "${e.prefix}"`;if(e.format==="ends_with")return`Невалиден низ: трябва да завършва с "${e.suffix}"`;if(e.format==="includes")return`Невалиден низ: трябва да включва "${e.includes}"`;if(e.format==="regex")return`Невалиден низ: трябва да съвпада с ${e.pattern}`;let t="Невалиден";return e.format==="emoji"&&(t="Невалидно"),e.format==="datetime"&&(t="Невалидно"),e.format==="date"&&(t="Невалидна"),e.format==="time"&&(t="Невалидно"),e.format==="duration"&&(t="Невалидна"),`${t} ${o[e.format]??n.format}`}case"not_multiple_of":return`Невалидно число: трябва да бъде кратно на ${n.divisor}`;case"unrecognized_keys":return`Неразпознат${n.keys.length>1?"и":""} ключ${n.keys.length>1?"ове":""}: ${c(n.keys,", ")}`;case"invalid_key":return`Невалиден ключ в ${n.origin}`;case"invalid_union":return"Невалиден вход";case"invalid_element":return`Невалидна стойност в ${n.origin}`;default:return"Невалиден вход"}}};function dc(){return{localeError:sc()}}const mc=()=>{const a={string:{unit:"caràcters",verb:"contenir"},file:{unit:"bytes",verb:"contenir"},array:{unit:"elements",verb:"contenir"},set:{unit:"elements",verb:"contenir"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"number";case"object":{if(Array.isArray(e))return"array";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"entrada",email:"adreça electrònica",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"data i hora ISO",date:"data ISO",time:"hora ISO",duration:"durada ISO",ipv4:"adreça IPv4",ipv6:"adreça IPv6",cidrv4:"rang IPv4",cidrv6:"rang IPv6",base64:"cadena codificada en base64",base64url:"cadena codificada en base64url",json_string:"cadena JSON",e164:"número E.164",jwt:"JWT",template_literal:"entrada"};return e=>{switch(e.code){case"invalid_type":return`Tipus invàlid: s'esperava ${e.expected}, s'ha rebut ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Valor invàlid: s'esperava ${v(e.values[0])}`:`Opció invàlida: s'esperava una de ${c(e.values," o ")}`;case"too_big":{const t=e.inclusive?"com a màxim":"menys de",r=i(e.origin);return r?`Massa gran: s'esperava que ${e.origin??"el valor"} contingués ${t} ${e.maximum.toString()} ${r.unit??"elements"}`:`Massa gran: s'esperava que ${e.origin??"el valor"} fos ${t} ${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?"com a mínim":"més de",r=i(e.origin);return r?`Massa petit: s'esperava que ${e.origin} contingués ${t} ${e.minimum.toString()} ${r.unit}`:`Massa petit: s'esperava que ${e.origin} fos ${t} ${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Format invàlid: ha de començar amb "${t.prefix}"`:t.format==="ends_with"?`Format invàlid: ha d'acabar amb "${t.suffix}"`:t.format==="includes"?`Format invàlid: ha d'incloure "${t.includes}"`:t.format==="regex"?`Format invàlid: ha de coincidir amb el patró ${t.pattern}`:`Format invàlid per a ${n[t.format]??e.format}`}case"not_multiple_of":return`Número invàlid: ha de ser múltiple de ${e.divisor}`;case"unrecognized_keys":return`Clau${e.keys.length>1?"s":""} no reconeguda${e.keys.length>1?"s":""}: ${c(e.keys,", ")}`;case"invalid_key":return`Clau invàlida a ${e.origin}`;case"invalid_union":return"Entrada invàlida";case"invalid_element":return`Element invàlid a ${e.origin}`;default:return"Entrada invàlida"}}};function fc(){return{localeError:mc()}}const gc=()=>{const a={string:{unit:"znaků",verb:"mít"},file:{unit:"bajtů",verb:"mít"},array:{unit:"prvků",verb:"mít"},set:{unit:"prvků",verb:"mít"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"číslo";case"string":return"řetězec";case"boolean":return"boolean";case"bigint":return"bigint";case"function":return"funkce";case"symbol":return"symbol";case"undefined":return"undefined";case"object":{if(Array.isArray(e))return"pole";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"regulární výraz",email:"e-mailová adresa",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"datum a čas ve formátu ISO",date:"datum ve formátu ISO",time:"čas ve formátu ISO",duration:"doba trvání ISO",ipv4:"IPv4 adresa",ipv6:"IPv6 adresa",cidrv4:"rozsah IPv4",cidrv6:"rozsah IPv6",base64:"řetězec zakódovaný ve formátu base64",base64url:"řetězec zakódovaný ve formátu base64url",json_string:"řetězec ve formátu JSON",e164:"číslo E.164",jwt:"JWT",template_literal:"vstup"};return e=>{switch(e.code){case"invalid_type":return`Neplatný vstup: očekáváno ${e.expected}, obdrženo ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Neplatný vstup: očekáváno ${v(e.values[0])}`:`Neplatná možnost: očekávána jedna z hodnot ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Hodnota je příliš velká: ${e.origin??"hodnota"} musí mít ${t}${e.maximum.toString()} ${r.unit??"prvků"}`:`Hodnota je příliš velká: ${e.origin??"hodnota"} musí být ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Hodnota je příliš malá: ${e.origin??"hodnota"} musí mít ${t}${e.minimum.toString()} ${r.unit??"prvků"}`:`Hodnota je příliš malá: ${e.origin??"hodnota"} musí být ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Neplatný řetězec: musí začínat na "${t.prefix}"`:t.format==="ends_with"?`Neplatný řetězec: musí končit na "${t.suffix}"`:t.format==="includes"?`Neplatný řetězec: musí obsahovat "${t.includes}"`:t.format==="regex"?`Neplatný řetězec: musí odpovídat vzoru ${t.pattern}`:`Neplatný formát ${n[t.format]??e.format}`}case"not_multiple_of":return`Neplatné číslo: musí být násobkem ${e.divisor}`;case"unrecognized_keys":return`Neznámé klíče: ${c(e.keys,", ")}`;case"invalid_key":return`Neplatný klíč v ${e.origin}`;case"invalid_union":return"Neplatný vstup";case"invalid_element":return`Neplatná hodnota v ${e.origin}`;default:return"Neplatný vstup"}}};function vc(){return{localeError:gc()}}const pc=()=>{const a={string:{unit:"tegn",verb:"havde"},file:{unit:"bytes",verb:"havde"},array:{unit:"elementer",verb:"indeholdt"},set:{unit:"elementer",verb:"indeholdt"}},i={string:"streng",number:"tal",boolean:"boolean",array:"liste",object:"objekt",set:"sæt",file:"fil"};function o(r){return a[r]??null}function n(r){return i[r]??r}const e=r=>{const u=typeof r;switch(u){case"number":return Number.isNaN(r)?"NaN":"tal";case"object":return Array.isArray(r)?"liste":r===null?"null":Object.getPrototypeOf(r)!==Object.prototype&&r.constructor?r.constructor.name:"objekt"}return u},t={regex:"input",email:"e-mailadresse",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO dato- og klokkeslæt",date:"ISO-dato",time:"ISO-klokkeslæt",duration:"ISO-varighed",ipv4:"IPv4-område",ipv6:"IPv6-område",cidrv4:"IPv4-spektrum",cidrv6:"IPv6-spektrum",base64:"base64-kodet streng",base64url:"base64url-kodet streng",json_string:"JSON-streng",e164:"E.164-nummer",jwt:"JWT",template_literal:"input"};return r=>{switch(r.code){case"invalid_type":return`Ugyldigt input: forventede ${n(r.expected)}, fik ${n(e(r.input))}`;case"invalid_value":return r.values.length===1?`Ugyldig værdi: forventede ${v(r.values[0])}`:`Ugyldigt valg: forventede en af følgende ${c(r.values,"|")}`;case"too_big":{const u=r.inclusive?"<=":"<",d=o(r.origin),p=n(r.origin);return d?`For stor: forventede ${p??"value"} ${d.verb} ${u} ${r.maximum.toString()} ${d.unit??"elementer"}`:`For stor: forventede ${p??"value"} havde ${u} ${r.maximum.toString()}`}case"too_small":{const u=r.inclusive?">=":">",d=o(r.origin),p=n(r.origin);return d?`For lille: forventede ${p} ${d.verb} ${u} ${r.minimum.toString()} ${d.unit}`:`For lille: forventede ${p} havde ${u} ${r.minimum.toString()}`}case"invalid_format":{const u=r;return u.format==="starts_with"?`Ugyldig streng: skal starte med "${u.prefix}"`:u.format==="ends_with"?`Ugyldig streng: skal ende med "${u.suffix}"`:u.format==="includes"?`Ugyldig streng: skal indeholde "${u.includes}"`:u.format==="regex"?`Ugyldig streng: skal matche mønsteret ${u.pattern}`:`Ugyldig ${t[u.format]??r.format}`}case"not_multiple_of":return`Ugyldigt tal: skal være deleligt med ${r.divisor}`;case"unrecognized_keys":return`${r.keys.length>1?"Ukendte nøgler":"Ukendt nøgle"}: ${c(r.keys,", ")}`;case"invalid_key":return`Ugyldig nøgle i ${r.origin}`;case"invalid_union":return"Ugyldigt input: matcher ingen af de tilladte typer";case"invalid_element":return`Ugyldig værdi i ${r.origin}`;default:return"Ugyldigt input"}}};function $c(){return{localeError:pc()}}const bc=()=>{const a={string:{unit:"Zeichen",verb:"zu haben"},file:{unit:"Bytes",verb:"zu haben"},array:{unit:"Elemente",verb:"zu haben"},set:{unit:"Elemente",verb:"zu haben"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"Zahl";case"object":{if(Array.isArray(e))return"Array";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"Eingabe",email:"E-Mail-Adresse",url:"URL",emoji:"Emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO-Datum und -Uhrzeit",date:"ISO-Datum",time:"ISO-Uhrzeit",duration:"ISO-Dauer",ipv4:"IPv4-Adresse",ipv6:"IPv6-Adresse",cidrv4:"IPv4-Bereich",cidrv6:"IPv6-Bereich",base64:"Base64-codierter String",base64url:"Base64-URL-codierter String",json_string:"JSON-String",e164:"E.164-Nummer",jwt:"JWT",template_literal:"Eingabe"};return e=>{switch(e.code){case"invalid_type":return`Ungültige Eingabe: erwartet ${e.expected}, erhalten ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Ungültige Eingabe: erwartet ${v(e.values[0])}`:`Ungültige Option: erwartet eine von ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Zu groß: erwartet, dass ${e.origin??"Wert"} ${t}${e.maximum.toString()} ${r.unit??"Elemente"} hat`:`Zu groß: erwartet, dass ${e.origin??"Wert"} ${t}${e.maximum.toString()} ist`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Zu klein: erwartet, dass ${e.origin} ${t}${e.minimum.toString()} ${r.unit} hat`:`Zu klein: erwartet, dass ${e.origin} ${t}${e.minimum.toString()} ist`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Ungültiger String: muss mit "${t.prefix}" beginnen`:t.format==="ends_with"?`Ungültiger String: muss mit "${t.suffix}" enden`:t.format==="includes"?`Ungültiger String: muss "${t.includes}" enthalten`:t.format==="regex"?`Ungültiger String: muss dem Muster ${t.pattern} entsprechen`:`Ungültig: ${n[t.format]??e.format}`}case"not_multiple_of":return`Ungültige Zahl: muss ein Vielfaches von ${e.divisor} sein`;case"unrecognized_keys":return`${e.keys.length>1?"Unbekannte Schlüssel":"Unbekannter Schlüssel"}: ${c(e.keys,", ")}`;case"invalid_key":return`Ungültiger Schlüssel in ${e.origin}`;case"invalid_union":return"Ungültige Eingabe";case"invalid_element":return`Ungültiger Wert in ${e.origin}`;default:return"Ungültige Eingabe"}}};function yc(){return{localeError:bc()}}const hc=a=>{const i=typeof a;switch(i){case"number":return Number.isNaN(a)?"NaN":"number";case"object":{if(Array.isArray(a))return"array";if(a===null)return"null";if(Object.getPrototypeOf(a)!==Object.prototype&&a.constructor)return a.constructor.name}}return i},_c=()=>{const a={string:{unit:"characters",verb:"to have"},file:{unit:"bytes",verb:"to have"},array:{unit:"items",verb:"to have"},set:{unit:"items",verb:"to have"}};function i(n){return a[n]??null}const o={regex:"input",email:"email address",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO datetime",date:"ISO date",time:"ISO time",duration:"ISO duration",ipv4:"IPv4 address",ipv6:"IPv6 address",cidrv4:"IPv4 range",cidrv6:"IPv6 range",base64:"base64-encoded string",base64url:"base64url-encoded string",json_string:"JSON string",e164:"E.164 number",jwt:"JWT",template_literal:"input"};return n=>{switch(n.code){case"invalid_type":return`Invalid input: expected ${n.expected}, received ${hc(n.input)}`;case"invalid_value":return n.values.length===1?`Invalid input: expected ${v(n.values[0])}`:`Invalid option: expected one of ${c(n.values,"|")}`;case"too_big":{const e=n.inclusive?"<=":"<",t=i(n.origin);return t?`Too big: expected ${n.origin??"value"} to have ${e}${n.maximum.toString()} ${t.unit??"elements"}`:`Too big: expected ${n.origin??"value"} to be ${e}${n.maximum.toString()}`}case"too_small":{const e=n.inclusive?">=":">",t=i(n.origin);return t?`Too small: expected ${n.origin} to have ${e}${n.minimum.toString()} ${t.unit}`:`Too small: expected ${n.origin} to be ${e}${n.minimum.toString()}`}case"invalid_format":{const e=n;return e.format==="starts_with"?`Invalid string: must start with "${e.prefix}"`:e.format==="ends_with"?`Invalid string: must end with "${e.suffix}"`:e.format==="includes"?`Invalid string: must include "${e.includes}"`:e.format==="regex"?`Invalid string: must match pattern ${e.pattern}`:`Invalid ${o[e.format]??n.format}`}case"not_multiple_of":return`Invalid number: must be a multiple of ${n.divisor}`;case"unrecognized_keys":return`Unrecognized key${n.keys.length>1?"s":""}: ${c(n.keys,", ")}`;case"invalid_key":return`Invalid key in ${n.origin}`;case"invalid_union":return"Invalid input";case"invalid_element":return`Invalid value in ${n.origin}`;default:return"Invalid input"}}};function _t(){return{localeError:_c()}}const kc=a=>{const i=typeof a;switch(i){case"number":return Number.isNaN(a)?"NaN":"nombro";case"object":{if(Array.isArray(a))return"tabelo";if(a===null)return"senvalora";if(Object.getPrototypeOf(a)!==Object.prototype&&a.constructor)return a.constructor.name}}return i},Ic=()=>{const a={string:{unit:"karaktrojn",verb:"havi"},file:{unit:"bajtojn",verb:"havi"},array:{unit:"elementojn",verb:"havi"},set:{unit:"elementojn",verb:"havi"}};function i(n){return a[n]??null}const o={regex:"enigo",email:"retadreso",url:"URL",emoji:"emoĝio",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO-datotempo",date:"ISO-dato",time:"ISO-tempo",duration:"ISO-daŭro",ipv4:"IPv4-adreso",ipv6:"IPv6-adreso",cidrv4:"IPv4-rango",cidrv6:"IPv6-rango",base64:"64-ume kodita karaktraro",base64url:"URL-64-ume kodita karaktraro",json_string:"JSON-karaktraro",e164:"E.164-nombro",jwt:"JWT",template_literal:"enigo"};return n=>{switch(n.code){case"invalid_type":return`Nevalida enigo: atendiĝis ${n.expected}, riceviĝis ${kc(n.input)}`;case"invalid_value":return n.values.length===1?`Nevalida enigo: atendiĝis ${v(n.values[0])}`:`Nevalida opcio: atendiĝis unu el ${c(n.values,"|")}`;case"too_big":{const e=n.inclusive?"<=":"<",t=i(n.origin);return t?`Tro granda: atendiĝis ke ${n.origin??"valoro"} havu ${e}${n.maximum.toString()} ${t.unit??"elementojn"}`:`Tro granda: atendiĝis ke ${n.origin??"valoro"} havu ${e}${n.maximum.toString()}`}case"too_small":{const e=n.inclusive?">=":">",t=i(n.origin);return t?`Tro malgranda: atendiĝis ke ${n.origin} havu ${e}${n.minimum.toString()} ${t.unit}`:`Tro malgranda: atendiĝis ke ${n.origin} estu ${e}${n.minimum.toString()}`}case"invalid_format":{const e=n;return e.format==="starts_with"?`Nevalida karaktraro: devas komenciĝi per "${e.prefix}"`:e.format==="ends_with"?`Nevalida karaktraro: devas finiĝi per "${e.suffix}"`:e.format==="includes"?`Nevalida karaktraro: devas inkluzivi "${e.includes}"`:e.format==="regex"?`Nevalida karaktraro: devas kongrui kun la modelo ${e.pattern}`:`Nevalida ${o[e.format]??n.format}`}case"not_multiple_of":return`Nevalida nombro: devas esti oblo de ${n.divisor}`;case"unrecognized_keys":return`Nekonata${n.keys.length>1?"j":""} ŝlosilo${n.keys.length>1?"j":""}: ${c(n.keys,", ")}`;case"invalid_key":return`Nevalida ŝlosilo en ${n.origin}`;case"invalid_union":return"Nevalida enigo";case"invalid_element":return`Nevalida valoro en ${n.origin}`;default:return"Nevalida enigo"}}};function Sc(){return{localeError:Ic()}}const jc=()=>{const a={string:{unit:"caracteres",verb:"tener"},file:{unit:"bytes",verb:"tener"},array:{unit:"elementos",verb:"tener"},set:{unit:"elementos",verb:"tener"}},i={string:"texto",number:"número",boolean:"booleano",array:"arreglo",object:"objeto",set:"conjunto",file:"archivo",date:"fecha",bigint:"número grande",symbol:"símbolo",undefined:"indefinido",null:"nulo",function:"función",map:"mapa",record:"registro",tuple:"tupla",enum:"enumeración",union:"unión",literal:"literal",promise:"promesa",void:"vacío",never:"nunca",unknown:"desconocido",any:"cualquiera"};function o(r){return a[r]??null}function n(r){return i[r]??r}const e=r=>{const u=typeof r;switch(u){case"number":return Number.isNaN(r)?"NaN":"number";case"object":return Array.isArray(r)?"array":r===null?"null":Object.getPrototypeOf(r)!==Object.prototype?r.constructor.name:"object"}return u},t={regex:"entrada",email:"dirección de correo electrónico",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"fecha y hora ISO",date:"fecha ISO",time:"hora ISO",duration:"duración ISO",ipv4:"dirección IPv4",ipv6:"dirección IPv6",cidrv4:"rango IPv4",cidrv6:"rango IPv6",base64:"cadena codificada en base64",base64url:"URL codificada en base64",json_string:"cadena JSON",e164:"número E.164",jwt:"JWT",template_literal:"entrada"};return r=>{switch(r.code){case"invalid_type":return`Entrada inválida: se esperaba ${n(r.expected)}, recibido ${n(e(r.input))}`;case"invalid_value":return r.values.length===1?`Entrada inválida: se esperaba ${v(r.values[0])}`:`Opción inválida: se esperaba una de ${c(r.values,"|")}`;case"too_big":{const u=r.inclusive?"<=":"<",d=o(r.origin),p=n(r.origin);return d?`Demasiado grande: se esperaba que ${p??"valor"} tuviera ${u}${r.maximum.toString()} ${d.unit??"elementos"}`:`Demasiado grande: se esperaba que ${p??"valor"} fuera ${u}${r.maximum.toString()}`}case"too_small":{const u=r.inclusive?">=":">",d=o(r.origin),p=n(r.origin);return d?`Demasiado pequeño: se esperaba que ${p} tuviera ${u}${r.minimum.toString()} ${d.unit}`:`Demasiado pequeño: se esperaba que ${p} fuera ${u}${r.minimum.toString()}`}case"invalid_format":{const u=r;return u.format==="starts_with"?`Cadena inválida: debe comenzar con "${u.prefix}"`:u.format==="ends_with"?`Cadena inválida: debe terminar en "${u.suffix}"`:u.format==="includes"?`Cadena inválida: debe incluir "${u.includes}"`:u.format==="regex"?`Cadena inválida: debe coincidir con el patrón ${u.pattern}`:`Inválido ${t[u.format]??r.format}`}case"not_multiple_of":return`Número inválido: debe ser múltiplo de ${r.divisor}`;case"unrecognized_keys":return`Llave${r.keys.length>1?"s":""} desconocida${r.keys.length>1?"s":""}: ${c(r.keys,", ")}`;case"invalid_key":return`Llave inválida en ${n(r.origin)}`;case"invalid_union":return"Entrada inválida";case"invalid_element":return`Valor inválido en ${n(r.origin)}`;default:return"Entrada inválida"}}};function xc(){return{localeError:jc()}}const Uc=()=>{const a={string:{unit:"کاراکتر",verb:"داشته باشد"},file:{unit:"بایت",verb:"داشته باشد"},array:{unit:"آیتم",verb:"داشته باشد"},set:{unit:"آیتم",verb:"داشته باشد"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"عدد";case"object":{if(Array.isArray(e))return"آرایه";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"ورودی",email:"آدرس ایمیل",url:"URL",emoji:"ایموجی",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"تاریخ و زمان ایزو",date:"تاریخ ایزو",time:"زمان ایزو",duration:"مدت زمان ایزو",ipv4:"IPv4 آدرس",ipv6:"IPv6 آدرس",cidrv4:"IPv4 دامنه",cidrv6:"IPv6 دامنه",base64:"base64-encoded رشته",base64url:"base64url-encoded رشته",json_string:"JSON رشته",e164:"E.164 عدد",jwt:"JWT",template_literal:"ورودی"};return e=>{switch(e.code){case"invalid_type":return`ورودی نامعتبر: می‌بایست ${e.expected} می‌بود، ${o(e.input)} دریافت شد`;case"invalid_value":return e.values.length===1?`ورودی نامعتبر: می‌بایست ${v(e.values[0])} می‌بود`:`گزینه نامعتبر: می‌بایست یکی از ${c(e.values,"|")} می‌بود`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`خیلی بزرگ: ${e.origin??"مقدار"} باید ${t}${e.maximum.toString()} ${r.unit??"عنصر"} باشد`:`خیلی بزرگ: ${e.origin??"مقدار"} باید ${t}${e.maximum.toString()} باشد`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`خیلی کوچک: ${e.origin} باید ${t}${e.minimum.toString()} ${r.unit} باشد`:`خیلی کوچک: ${e.origin} باید ${t}${e.minimum.toString()} باشد`}case"invalid_format":{const t=e;return t.format==="starts_with"?`رشته نامعتبر: باید با "${t.prefix}" شروع شود`:t.format==="ends_with"?`رشته نامعتبر: باید با "${t.suffix}" تمام شود`:t.format==="includes"?`رشته نامعتبر: باید شامل "${t.includes}" باشد`:t.format==="regex"?`رشته نامعتبر: باید با الگوی ${t.pattern} مطابقت داشته باشد`:`${n[t.format]??e.format} نامعتبر`}case"not_multiple_of":return`عدد نامعتبر: باید مضرب ${e.divisor} باشد`;case"unrecognized_keys":return`کلید${e.keys.length>1?"های":""} ناشناس: ${c(e.keys,", ")}`;case"invalid_key":return`کلید ناشناس در ${e.origin}`;case"invalid_union":return"ورودی نامعتبر";case"invalid_element":return`مقدار نامعتبر در ${e.origin}`;default:return"ورودی نامعتبر"}}};function Oc(){return{localeError:Uc()}}const wc=()=>{const a={string:{unit:"merkkiä",subject:"merkkijonon"},file:{unit:"tavua",subject:"tiedoston"},array:{unit:"alkiota",subject:"listan"},set:{unit:"alkiota",subject:"joukon"},number:{unit:"",subject:"luvun"},bigint:{unit:"",subject:"suuren kokonaisluvun"},int:{unit:"",subject:"kokonaisluvun"},date:{unit:"",subject:"päivämäärän"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"number";case"object":{if(Array.isArray(e))return"array";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"säännöllinen lauseke",email:"sähköpostiosoite",url:"URL-osoite",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO-aikaleima",date:"ISO-päivämäärä",time:"ISO-aika",duration:"ISO-kesto",ipv4:"IPv4-osoite",ipv6:"IPv6-osoite",cidrv4:"IPv4-alue",cidrv6:"IPv6-alue",base64:"base64-koodattu merkkijono",base64url:"base64url-koodattu merkkijono",json_string:"JSON-merkkijono",e164:"E.164-luku",jwt:"JWT",template_literal:"templaattimerkkijono"};return e=>{switch(e.code){case"invalid_type":return`Virheellinen tyyppi: odotettiin ${e.expected}, oli ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Virheellinen syöte: täytyy olla ${v(e.values[0])}`:`Virheellinen valinta: täytyy olla yksi seuraavista: ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Liian suuri: ${r.subject} täytyy olla ${t}${e.maximum.toString()} ${r.unit}`.trim():`Liian suuri: arvon täytyy olla ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Liian pieni: ${r.subject} täytyy olla ${t}${e.minimum.toString()} ${r.unit}`.trim():`Liian pieni: arvon täytyy olla ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Virheellinen syöte: täytyy alkaa "${t.prefix}"`:t.format==="ends_with"?`Virheellinen syöte: täytyy loppua "${t.suffix}"`:t.format==="includes"?`Virheellinen syöte: täytyy sisältää "${t.includes}"`:t.format==="regex"?`Virheellinen syöte: täytyy vastata säännöllistä lauseketta ${t.pattern}`:`Virheellinen ${n[t.format]??e.format}`}case"not_multiple_of":return`Virheellinen luku: täytyy olla luvun ${e.divisor} monikerta`;case"unrecognized_keys":return`${e.keys.length>1?"Tuntemattomat avaimet":"Tuntematon avain"}: ${c(e.keys,", ")}`;case"invalid_key":return"Virheellinen avain tietueessa";case"invalid_union":return"Virheellinen unioni";case"invalid_element":return"Virheellinen arvo joukossa";default:return"Virheellinen syöte"}}};function Nc(){return{localeError:wc()}}const zc=()=>{const a={string:{unit:"caractères",verb:"avoir"},file:{unit:"octets",verb:"avoir"},array:{unit:"éléments",verb:"avoir"},set:{unit:"éléments",verb:"avoir"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"nombre";case"object":{if(Array.isArray(e))return"tableau";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"entrée",email:"adresse e-mail",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"date et heure ISO",date:"date ISO",time:"heure ISO",duration:"durée ISO",ipv4:"adresse IPv4",ipv6:"adresse IPv6",cidrv4:"plage IPv4",cidrv6:"plage IPv6",base64:"chaîne encodée en base64",base64url:"chaîne encodée en base64url",json_string:"chaîne JSON",e164:"numéro E.164",jwt:"JWT",template_literal:"entrée"};return e=>{switch(e.code){case"invalid_type":return`Entrée invalide : ${e.expected} attendu, ${o(e.input)} reçu`;case"invalid_value":return e.values.length===1?`Entrée invalide : ${v(e.values[0])} attendu`:`Option invalide : une valeur parmi ${c(e.values,"|")} attendue`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Trop grand : ${e.origin??"valeur"} doit ${r.verb} ${t}${e.maximum.toString()} ${r.unit??"élément(s)"}`:`Trop grand : ${e.origin??"valeur"} doit être ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Trop petit : ${e.origin} doit ${r.verb} ${t}${e.minimum.toString()} ${r.unit}`:`Trop petit : ${e.origin} doit être ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Chaîne invalide : doit commencer par "${t.prefix}"`:t.format==="ends_with"?`Chaîne invalide : doit se terminer par "${t.suffix}"`:t.format==="includes"?`Chaîne invalide : doit inclure "${t.includes}"`:t.format==="regex"?`Chaîne invalide : doit correspondre au modèle ${t.pattern}`:`${n[t.format]??e.format} invalide`}case"not_multiple_of":return`Nombre invalide : doit être un multiple de ${e.divisor}`;case"unrecognized_keys":return`Clé${e.keys.length>1?"s":""} non reconnue${e.keys.length>1?"s":""} : ${c(e.keys,", ")}`;case"invalid_key":return`Clé invalide dans ${e.origin}`;case"invalid_union":return"Entrée invalide";case"invalid_element":return`Valeur invalide dans ${e.origin}`;default:return"Entrée invalide"}}};function Dc(){return{localeError:zc()}}const Pc=()=>{const a={string:{unit:"caractères",verb:"avoir"},file:{unit:"octets",verb:"avoir"},array:{unit:"éléments",verb:"avoir"},set:{unit:"éléments",verb:"avoir"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"number";case"object":{if(Array.isArray(e))return"array";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"entrée",email:"adresse courriel",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"date-heure ISO",date:"date ISO",time:"heure ISO",duration:"durée ISO",ipv4:"adresse IPv4",ipv6:"adresse IPv6",cidrv4:"plage IPv4",cidrv6:"plage IPv6",base64:"chaîne encodée en base64",base64url:"chaîne encodée en base64url",json_string:"chaîne JSON",e164:"numéro E.164",jwt:"JWT",template_literal:"entrée"};return e=>{switch(e.code){case"invalid_type":return`Entrée invalide : attendu ${e.expected}, reçu ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Entrée invalide : attendu ${v(e.values[0])}`:`Option invalide : attendu l'une des valeurs suivantes ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"≤":"<",r=i(e.origin);return r?`Trop grand : attendu que ${e.origin??"la valeur"} ait ${t}${e.maximum.toString()} ${r.unit}`:`Trop grand : attendu que ${e.origin??"la valeur"} soit ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?"≥":">",r=i(e.origin);return r?`Trop petit : attendu que ${e.origin} ait ${t}${e.minimum.toString()} ${r.unit}`:`Trop petit : attendu que ${e.origin} soit ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Chaîne invalide : doit commencer par "${t.prefix}"`:t.format==="ends_with"?`Chaîne invalide : doit se terminer par "${t.suffix}"`:t.format==="includes"?`Chaîne invalide : doit inclure "${t.includes}"`:t.format==="regex"?`Chaîne invalide : doit correspondre au motif ${t.pattern}`:`${n[t.format]??e.format} invalide`}case"not_multiple_of":return`Nombre invalide : doit être un multiple de ${e.divisor}`;case"unrecognized_keys":return`Clé${e.keys.length>1?"s":""} non reconnue${e.keys.length>1?"s":""} : ${c(e.keys,", ")}`;case"invalid_key":return`Clé invalide dans ${e.origin}`;case"invalid_union":return"Entrée invalide";case"invalid_element":return`Valeur invalide dans ${e.origin}`;default:return"Entrée invalide"}}};function Tc(){return{localeError:Pc()}}const Ec=()=>{const a={string:{unit:"אותיות",verb:"לכלול"},file:{unit:"בייטים",verb:"לכלול"},array:{unit:"פריטים",verb:"לכלול"},set:{unit:"פריטים",verb:"לכלול"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"number";case"object":{if(Array.isArray(e))return"array";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"קלט",email:"כתובת אימייל",url:"כתובת רשת",emoji:"אימוג'י",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"תאריך וזמן ISO",date:"תאריך ISO",time:"זמן ISO",duration:"משך זמן ISO",ipv4:"כתובת IPv4",ipv6:"כתובת IPv6",cidrv4:"טווח IPv4",cidrv6:"טווח IPv6",base64:"מחרוזת בבסיס 64",base64url:"מחרוזת בבסיס 64 לכתובות רשת",json_string:"מחרוזת JSON",e164:"מספר E.164",jwt:"JWT",template_literal:"קלט"};return e=>{switch(e.code){case"invalid_type":return`קלט לא תקין: צריך ${e.expected}, התקבל ${o(e.input)}`;case"invalid_value":return e.values.length===1?`קלט לא תקין: צריך ${v(e.values[0])}`:`קלט לא תקין: צריך אחת מהאפשרויות  ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`גדול מדי: ${e.origin??"value"} צריך להיות ${t}${e.maximum.toString()} ${r.unit??"elements"}`:`גדול מדי: ${e.origin??"value"} צריך להיות ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`קטן מדי: ${e.origin} צריך להיות ${t}${e.minimum.toString()} ${r.unit}`:`קטן מדי: ${e.origin} צריך להיות ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`מחרוזת לא תקינה: חייבת להתחיל ב"${t.prefix}"`:t.format==="ends_with"?`מחרוזת לא תקינה: חייבת להסתיים ב "${t.suffix}"`:t.format==="includes"?`מחרוזת לא תקינה: חייבת לכלול "${t.includes}"`:t.format==="regex"?`מחרוזת לא תקינה: חייבת להתאים לתבנית ${t.pattern}`:`${n[t.format]??e.format} לא תקין`}case"not_multiple_of":return`מספר לא תקין: חייב להיות מכפלה של ${e.divisor}`;case"unrecognized_keys":return`מפתח${e.keys.length>1?"ות":""} לא מזוה${e.keys.length>1?"ים":"ה"}: ${c(e.keys,", ")}`;case"invalid_key":return`מפתח לא תקין ב${e.origin}`;case"invalid_union":return"קלט לא תקין";case"invalid_element":return`ערך לא תקין ב${e.origin}`;default:return"קלט לא תקין"}}};function Ac(){return{localeError:Ec()}}const Zc=()=>{const a={string:{unit:"karakter",verb:"legyen"},file:{unit:"byte",verb:"legyen"},array:{unit:"elem",verb:"legyen"},set:{unit:"elem",verb:"legyen"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"szám";case"object":{if(Array.isArray(e))return"tömb";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"bemenet",email:"email cím",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO időbélyeg",date:"ISO dátum",time:"ISO idő",duration:"ISO időintervallum",ipv4:"IPv4 cím",ipv6:"IPv6 cím",cidrv4:"IPv4 tartomány",cidrv6:"IPv6 tartomány",base64:"base64-kódolt string",base64url:"base64url-kódolt string",json_string:"JSON string",e164:"E.164 szám",jwt:"JWT",template_literal:"bemenet"};return e=>{switch(e.code){case"invalid_type":return`Érvénytelen bemenet: a várt érték ${e.expected}, a kapott érték ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Érvénytelen bemenet: a várt érték ${v(e.values[0])}`:`Érvénytelen opció: valamelyik érték várt ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Túl nagy: ${e.origin??"érték"} mérete túl nagy ${t}${e.maximum.toString()} ${r.unit??"elem"}`:`Túl nagy: a bemeneti érték ${e.origin??"érték"} túl nagy: ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Túl kicsi: a bemeneti érték ${e.origin} mérete túl kicsi ${t}${e.minimum.toString()} ${r.unit}`:`Túl kicsi: a bemeneti érték ${e.origin} túl kicsi ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Érvénytelen string: "${t.prefix}" értékkel kell kezdődnie`:t.format==="ends_with"?`Érvénytelen string: "${t.suffix}" értékkel kell végződnie`:t.format==="includes"?`Érvénytelen string: "${t.includes}" értéket kell tartalmaznia`:t.format==="regex"?`Érvénytelen string: ${t.pattern} mintának kell megfelelnie`:`Érvénytelen ${n[t.format]??e.format}`}case"not_multiple_of":return`Érvénytelen szám: ${e.divisor} többszörösének kell lennie`;case"unrecognized_keys":return`Ismeretlen kulcs${e.keys.length>1?"s":""}: ${c(e.keys,", ")}`;case"invalid_key":return`Érvénytelen kulcs ${e.origin}`;case"invalid_union":return"Érvénytelen bemenet";case"invalid_element":return`Érvénytelen érték: ${e.origin}`;default:return"Érvénytelen bemenet"}}};function Cc(){return{localeError:Zc()}}const Lc=()=>{const a={string:{unit:"karakter",verb:"memiliki"},file:{unit:"byte",verb:"memiliki"},array:{unit:"item",verb:"memiliki"},set:{unit:"item",verb:"memiliki"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"number";case"object":{if(Array.isArray(e))return"array";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"input",email:"alamat email",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"tanggal dan waktu format ISO",date:"tanggal format ISO",time:"jam format ISO",duration:"durasi format ISO",ipv4:"alamat IPv4",ipv6:"alamat IPv6",cidrv4:"rentang alamat IPv4",cidrv6:"rentang alamat IPv6",base64:"string dengan enkode base64",base64url:"string dengan enkode base64url",json_string:"string JSON",e164:"angka E.164",jwt:"JWT",template_literal:"input"};return e=>{switch(e.code){case"invalid_type":return`Input tidak valid: diharapkan ${e.expected}, diterima ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Input tidak valid: diharapkan ${v(e.values[0])}`:`Pilihan tidak valid: diharapkan salah satu dari ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Terlalu besar: diharapkan ${e.origin??"value"} memiliki ${t}${e.maximum.toString()} ${r.unit??"elemen"}`:`Terlalu besar: diharapkan ${e.origin??"value"} menjadi ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Terlalu kecil: diharapkan ${e.origin} memiliki ${t}${e.minimum.toString()} ${r.unit}`:`Terlalu kecil: diharapkan ${e.origin} menjadi ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`String tidak valid: harus dimulai dengan "${t.prefix}"`:t.format==="ends_with"?`String tidak valid: harus berakhir dengan "${t.suffix}"`:t.format==="includes"?`String tidak valid: harus menyertakan "${t.includes}"`:t.format==="regex"?`String tidak valid: harus sesuai pola ${t.pattern}`:`${n[t.format]??e.format} tidak valid`}case"not_multiple_of":return`Angka tidak valid: harus kelipatan dari ${e.divisor}`;case"unrecognized_keys":return`Kunci tidak dikenali ${e.keys.length>1?"s":""}: ${c(e.keys,", ")}`;case"invalid_key":return`Kunci tidak valid di ${e.origin}`;case"invalid_union":return"Input tidak valid";case"invalid_element":return`Nilai tidak valid di ${e.origin}`;default:return"Input tidak valid"}}};function Rc(){return{localeError:Lc()}}const Jc=a=>{const i=typeof a;switch(i){case"number":return Number.isNaN(a)?"NaN":"númer";case"object":{if(Array.isArray(a))return"fylki";if(a===null)return"null";if(Object.getPrototypeOf(a)!==Object.prototype&&a.constructor)return a.constructor.name}}return i},Fc=()=>{const a={string:{unit:"stafi",verb:"að hafa"},file:{unit:"bæti",verb:"að hafa"},array:{unit:"hluti",verb:"að hafa"},set:{unit:"hluti",verb:"að hafa"}};function i(n){return a[n]??null}const o={regex:"gildi",email:"netfang",url:"vefslóð",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO dagsetning og tími",date:"ISO dagsetning",time:"ISO tími",duration:"ISO tímalengd",ipv4:"IPv4 address",ipv6:"IPv6 address",cidrv4:"IPv4 range",cidrv6:"IPv6 range",base64:"base64-encoded strengur",base64url:"base64url-encoded strengur",json_string:"JSON strengur",e164:"E.164 tölugildi",jwt:"JWT",template_literal:"gildi"};return n=>{switch(n.code){case"invalid_type":return`Rangt gildi: Þú slóst inn ${Jc(n.input)} þar sem á að vera ${n.expected}`;case"invalid_value":return n.values.length===1?`Rangt gildi: gert ráð fyrir ${v(n.values[0])}`:`Ógilt val: má vera eitt af eftirfarandi ${c(n.values,"|")}`;case"too_big":{const e=n.inclusive?"<=":"<",t=i(n.origin);return t?`Of stórt: gert er ráð fyrir að ${n.origin??"gildi"} hafi ${e}${n.maximum.toString()} ${t.unit??"hluti"}`:`Of stórt: gert er ráð fyrir að ${n.origin??"gildi"} sé ${e}${n.maximum.toString()}`}case"too_small":{const e=n.inclusive?">=":">",t=i(n.origin);return t?`Of lítið: gert er ráð fyrir að ${n.origin} hafi ${e}${n.minimum.toString()} ${t.unit}`:`Of lítið: gert er ráð fyrir að ${n.origin} sé ${e}${n.minimum.toString()}`}case"invalid_format":{const e=n;return e.format==="starts_with"?`Ógildur strengur: verður að byrja á "${e.prefix}"`:e.format==="ends_with"?`Ógildur strengur: verður að enda á "${e.suffix}"`:e.format==="includes"?`Ógildur strengur: verður að innihalda "${e.includes}"`:e.format==="regex"?`Ógildur strengur: verður að fylgja mynstri ${e.pattern}`:`Rangt ${o[e.format]??n.format}`}case"not_multiple_of":return`Röng tala: verður að vera margfeldi af ${n.divisor}`;case"unrecognized_keys":return`Óþekkt ${n.keys.length>1?"ir lyklar":"ur lykill"}: ${c(n.keys,", ")}`;case"invalid_key":return`Rangur lykill í ${n.origin}`;case"invalid_union":return"Rangt gildi";case"invalid_element":return`Rangt gildi í ${n.origin}`;default:return"Rangt gildi"}}};function Mc(){return{localeError:Fc()}}const Kc=()=>{const a={string:{unit:"caratteri",verb:"avere"},file:{unit:"byte",verb:"avere"},array:{unit:"elementi",verb:"avere"},set:{unit:"elementi",verb:"avere"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"numero";case"object":{if(Array.isArray(e))return"vettore";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"input",email:"indirizzo email",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"data e ora ISO",date:"data ISO",time:"ora ISO",duration:"durata ISO",ipv4:"indirizzo IPv4",ipv6:"indirizzo IPv6",cidrv4:"intervallo IPv4",cidrv6:"intervallo IPv6",base64:"stringa codificata in base64",base64url:"URL codificata in base64",json_string:"stringa JSON",e164:"numero E.164",jwt:"JWT",template_literal:"input"};return e=>{switch(e.code){case"invalid_type":return`Input non valido: atteso ${e.expected}, ricevuto ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Input non valido: atteso ${v(e.values[0])}`:`Opzione non valida: atteso uno tra ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Troppo grande: ${e.origin??"valore"} deve avere ${t}${e.maximum.toString()} ${r.unit??"elementi"}`:`Troppo grande: ${e.origin??"valore"} deve essere ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Troppo piccolo: ${e.origin} deve avere ${t}${e.minimum.toString()} ${r.unit}`:`Troppo piccolo: ${e.origin} deve essere ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Stringa non valida: deve iniziare con "${t.prefix}"`:t.format==="ends_with"?`Stringa non valida: deve terminare con "${t.suffix}"`:t.format==="includes"?`Stringa non valida: deve includere "${t.includes}"`:t.format==="regex"?`Stringa non valida: deve corrispondere al pattern ${t.pattern}`:`Invalid ${n[t.format]??e.format}`}case"not_multiple_of":return`Numero non valido: deve essere un multiplo di ${e.divisor}`;case"unrecognized_keys":return`Chiav${e.keys.length>1?"i":"e"} non riconosciut${e.keys.length>1?"e":"a"}: ${c(e.keys,", ")}`;case"invalid_key":return`Chiave non valida in ${e.origin}`;case"invalid_union":return"Input non valido";case"invalid_element":return`Valore non valido in ${e.origin}`;default:return"Input non valido"}}};function Gc(){return{localeError:Kc()}}const Wc=()=>{const a={string:{unit:"文字",verb:"である"},file:{unit:"バイト",verb:"である"},array:{unit:"要素",verb:"である"},set:{unit:"要素",verb:"である"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"数値";case"object":{if(Array.isArray(e))return"配列";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"入力値",email:"メールアドレス",url:"URL",emoji:"絵文字",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO日時",date:"ISO日付",time:"ISO時刻",duration:"ISO期間",ipv4:"IPv4アドレス",ipv6:"IPv6アドレス",cidrv4:"IPv4範囲",cidrv6:"IPv6範囲",base64:"base64エンコード文字列",base64url:"base64urlエンコード文字列",json_string:"JSON文字列",e164:"E.164番号",jwt:"JWT",template_literal:"入力値"};return e=>{switch(e.code){case"invalid_type":return`無効な入力: ${e.expected}が期待されましたが、${o(e.input)}が入力されました`;case"invalid_value":return e.values.length===1?`無効な入力: ${v(e.values[0])}が期待されました`:`無効な選択: ${c(e.values,"、")}のいずれかである必要があります`;case"too_big":{const t=e.inclusive?"以下である":"より小さい",r=i(e.origin);return r?`大きすぎる値: ${e.origin??"値"}は${e.maximum.toString()}${r.unit??"要素"}${t}必要があります`:`大きすぎる値: ${e.origin??"値"}は${e.maximum.toString()}${t}必要があります`}case"too_small":{const t=e.inclusive?"以上である":"より大きい",r=i(e.origin);return r?`小さすぎる値: ${e.origin}は${e.minimum.toString()}${r.unit}${t}必要があります`:`小さすぎる値: ${e.origin}は${e.minimum.toString()}${t}必要があります`}case"invalid_format":{const t=e;return t.format==="starts_with"?`無効な文字列: "${t.prefix}"で始まる必要があります`:t.format==="ends_with"?`無効な文字列: "${t.suffix}"で終わる必要があります`:t.format==="includes"?`無効な文字列: "${t.includes}"を含む必要があります`:t.format==="regex"?`無効な文字列: パターン${t.pattern}に一致する必要があります`:`無効な${n[t.format]??e.format}`}case"not_multiple_of":return`無効な数値: ${e.divisor}の倍数である必要があります`;case"unrecognized_keys":return`認識されていないキー${e.keys.length>1?"群":""}: ${c(e.keys,"、")}`;case"invalid_key":return`${e.origin}内の無効なキー`;case"invalid_union":return"無効な入力";case"invalid_element":return`${e.origin}内の無効な値`;default:return"無効な入力"}}};function Bc(){return{localeError:Wc()}}const Xc=a=>{const i=typeof a;switch(i){case"number":return Number.isNaN(a)?"NaN":"რიცხვი";case"object":{if(Array.isArray(a))return"მასივი";if(a===null)return"null";if(Object.getPrototypeOf(a)!==Object.prototype&&a.constructor)return a.constructor.name}}return{string:"სტრინგი",boolean:"ბულეანი",undefined:"undefined",bigint:"bigint",symbol:"symbol",function:"ფუნქცია"}[i]??i},Vc=()=>{const a={string:{unit:"სიმბოლო",verb:"უნდა შეიცავდეს"},file:{unit:"ბაიტი",verb:"უნდა შეიცავდეს"},array:{unit:"ელემენტი",verb:"უნდა შეიცავდეს"},set:{unit:"ელემენტი",verb:"უნდა შეიცავდეს"}};function i(n){return a[n]??null}const o={regex:"შეყვანა",email:"ელ-ფოსტის მისამართი",url:"URL",emoji:"ემოჯი",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"თარიღი-დრო",date:"თარიღი",time:"დრო",duration:"ხანგრძლივობა",ipv4:"IPv4 მისამართი",ipv6:"IPv6 მისამართი",cidrv4:"IPv4 დიაპაზონი",cidrv6:"IPv6 დიაპაზონი",base64:"base64-კოდირებული სტრინგი",base64url:"base64url-კოდირებული სტრინგი",json_string:"JSON სტრინგი",e164:"E.164 ნომერი",jwt:"JWT",template_literal:"შეყვანა"};return n=>{switch(n.code){case"invalid_type":return`არასწორი შეყვანა: მოსალოდნელი ${n.expected}, მიღებული ${Xc(n.input)}`;case"invalid_value":return n.values.length===1?`არასწორი შეყვანა: მოსალოდნელი ${v(n.values[0])}`:`არასწორი ვარიანტი: მოსალოდნელია ერთ-ერთი ${c(n.values,"|")}-დან`;case"too_big":{const e=n.inclusive?"<=":"<",t=i(n.origin);return t?`ზედმეტად დიდი: მოსალოდნელი ${n.origin??"მნიშვნელობა"} ${t.verb} ${e}${n.maximum.toString()} ${t.unit}`:`ზედმეტად დიდი: მოსალოდნელი ${n.origin??"მნიშვნელობა"} იყოს ${e}${n.maximum.toString()}`}case"too_small":{const e=n.inclusive?">=":">",t=i(n.origin);return t?`ზედმეტად პატარა: მოსალოდნელი ${n.origin} ${t.verb} ${e}${n.minimum.toString()} ${t.unit}`:`ზედმეტად პატარა: მოსალოდნელი ${n.origin} იყოს ${e}${n.minimum.toString()}`}case"invalid_format":{const e=n;return e.format==="starts_with"?`არასწორი სტრინგი: უნდა იწყებოდეს "${e.prefix}"-ით`:e.format==="ends_with"?`არასწორი სტრინგი: უნდა მთავრდებოდეს "${e.suffix}"-ით`:e.format==="includes"?`არასწორი სტრინგი: უნდა შეიცავდეს "${e.includes}"-ს`:e.format==="regex"?`არასწორი სტრინგი: უნდა შეესაბამებოდეს შაბლონს ${e.pattern}`:`არასწორი ${o[e.format]??n.format}`}case"not_multiple_of":return`არასწორი რიცხვი: უნდა იყოს ${n.divisor}-ის ჯერადი`;case"unrecognized_keys":return`უცნობი გასაღებ${n.keys.length>1?"ები":"ი"}: ${c(n.keys,", ")}`;case"invalid_key":return`არასწორი გასაღები ${n.origin}-ში`;case"invalid_union":return"არასწორი შეყვანა";case"invalid_element":return`არასწორი მნიშვნელობა ${n.origin}-ში`;default:return"არასწორი შეყვანა"}}};function qc(){return{localeError:Vc()}}const Yc=()=>{const a={string:{unit:"តួអក្សរ",verb:"គួរមាន"},file:{unit:"បៃ",verb:"គួរមាន"},array:{unit:"ធាតុ",verb:"គួរមាន"},set:{unit:"ធាតុ",verb:"គួរមាន"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"មិនមែនជាលេខ (NaN)":"លេខ";case"object":{if(Array.isArray(e))return"អារេ (Array)";if(e===null)return"គ្មានតម្លៃ (null)";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"ទិន្នន័យបញ្ចូល",email:"អាសយដ្ឋានអ៊ីមែល",url:"URL",emoji:"សញ្ញាអារម្មណ៍",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"កាលបរិច្ឆេទ និងម៉ោង ISO",date:"កាលបរិច្ឆេទ ISO",time:"ម៉ោង ISO",duration:"រយៈពេល ISO",ipv4:"អាសយដ្ឋាន IPv4",ipv6:"អាសយដ្ឋាន IPv6",cidrv4:"ដែនអាសយដ្ឋាន IPv4",cidrv6:"ដែនអាសយដ្ឋាន IPv6",base64:"ខ្សែអក្សរអ៊ិកូដ base64",base64url:"ខ្សែអក្សរអ៊ិកូដ base64url",json_string:"ខ្សែអក្សរ JSON",e164:"លេខ E.164",jwt:"JWT",template_literal:"ទិន្នន័យបញ្ចូល"};return e=>{switch(e.code){case"invalid_type":return`ទិន្នន័យបញ្ចូលមិនត្រឹមត្រូវ៖ ត្រូវការ ${e.expected} ប៉ុន្តែទទួលបាន ${o(e.input)}`;case"invalid_value":return e.values.length===1?`ទិន្នន័យបញ្ចូលមិនត្រឹមត្រូវ៖ ត្រូវការ ${v(e.values[0])}`:`ជម្រើសមិនត្រឹមត្រូវ៖ ត្រូវជាមួយក្នុងចំណោម ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`ធំពេក៖ ត្រូវការ ${e.origin??"តម្លៃ"} ${t} ${e.maximum.toString()} ${r.unit??"ធាតុ"}`:`ធំពេក៖ ត្រូវការ ${e.origin??"តម្លៃ"} ${t} ${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`តូចពេក៖ ត្រូវការ ${e.origin} ${t} ${e.minimum.toString()} ${r.unit}`:`តូចពេក៖ ត្រូវការ ${e.origin} ${t} ${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`ខ្សែអក្សរមិនត្រឹមត្រូវ៖ ត្រូវចាប់ផ្តើមដោយ "${t.prefix}"`:t.format==="ends_with"?`ខ្សែអក្សរមិនត្រឹមត្រូវ៖ ត្រូវបញ្ចប់ដោយ "${t.suffix}"`:t.format==="includes"?`ខ្សែអក្សរមិនត្រឹមត្រូវ៖ ត្រូវមាន "${t.includes}"`:t.format==="regex"?`ខ្សែអក្សរមិនត្រឹមត្រូវ៖ ត្រូវតែផ្គូផ្គងនឹងទម្រង់ដែលបានកំណត់ ${t.pattern}`:`មិនត្រឹមត្រូវ៖ ${n[t.format]??e.format}`}case"not_multiple_of":return`លេខមិនត្រឹមត្រូវ៖ ត្រូវតែជាពហុគុណនៃ ${e.divisor}`;case"unrecognized_keys":return`រកឃើញសោមិនស្គាល់៖ ${c(e.keys,", ")}`;case"invalid_key":return`សោមិនត្រឹមត្រូវនៅក្នុង ${e.origin}`;case"invalid_union":return"ទិន្នន័យមិនត្រឹមត្រូវ";case"invalid_element":return`ទិន្នន័យមិនត្រឹមត្រូវនៅក្នុង ${e.origin}`;default:return"ទិន្នន័យមិនត្រឹមត្រូវ"}}};function kt(){return{localeError:Yc()}}function Hc(){return kt()}const Qc=()=>{const a={string:{unit:"문자",verb:"to have"},file:{unit:"바이트",verb:"to have"},array:{unit:"개",verb:"to have"},set:{unit:"개",verb:"to have"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"number";case"object":{if(Array.isArray(e))return"array";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"입력",email:"이메일 주소",url:"URL",emoji:"이모지",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO 날짜시간",date:"ISO 날짜",time:"ISO 시간",duration:"ISO 기간",ipv4:"IPv4 주소",ipv6:"IPv6 주소",cidrv4:"IPv4 범위",cidrv6:"IPv6 범위",base64:"base64 인코딩 문자열",base64url:"base64url 인코딩 문자열",json_string:"JSON 문자열",e164:"E.164 번호",jwt:"JWT",template_literal:"입력"};return e=>{switch(e.code){case"invalid_type":return`잘못된 입력: 예상 타입은 ${e.expected}, 받은 타입은 ${o(e.input)}입니다`;case"invalid_value":return e.values.length===1?`잘못된 입력: 값은 ${v(e.values[0])} 이어야 합니다`:`잘못된 옵션: ${c(e.values,"또는 ")} 중 하나여야 합니다`;case"too_big":{const t=e.inclusive?"이하":"미만",r=t==="미만"?"이어야 합니다":"여야 합니다",u=i(e.origin),d=(u==null?void 0:u.unit)??"요소";return u?`${e.origin??"값"}이 너무 큽니다: ${e.maximum.toString()}${d} ${t}${r}`:`${e.origin??"값"}이 너무 큽니다: ${e.maximum.toString()} ${t}${r}`}case"too_small":{const t=e.inclusive?"이상":"초과",r=t==="이상"?"이어야 합니다":"여야 합니다",u=i(e.origin),d=(u==null?void 0:u.unit)??"요소";return u?`${e.origin??"값"}이 너무 작습니다: ${e.minimum.toString()}${d} ${t}${r}`:`${e.origin??"값"}이 너무 작습니다: ${e.minimum.toString()} ${t}${r}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`잘못된 문자열: "${t.prefix}"(으)로 시작해야 합니다`:t.format==="ends_with"?`잘못된 문자열: "${t.suffix}"(으)로 끝나야 합니다`:t.format==="includes"?`잘못된 문자열: "${t.includes}"을(를) 포함해야 합니다`:t.format==="regex"?`잘못된 문자열: 정규식 ${t.pattern} 패턴과 일치해야 합니다`:`잘못된 ${n[t.format]??e.format}`}case"not_multiple_of":return`잘못된 숫자: ${e.divisor}의 배수여야 합니다`;case"unrecognized_keys":return`인식할 수 없는 키: ${c(e.keys,", ")}`;case"invalid_key":return`잘못된 키: ${e.origin}`;case"invalid_union":return"잘못된 입력";case"invalid_element":return`잘못된 값: ${e.origin}`;default:return"잘못된 입력"}}};function es(){return{localeError:Qc()}}const ts=a=>G(typeof a,a),G=(a,i=void 0)=>{switch(a){case"number":return Number.isNaN(i)?"NaN":"skaičius";case"bigint":return"sveikasis skaičius";case"string":return"eilutė";case"boolean":return"loginė reikšmė";case"undefined":case"void":return"neapibrėžta reikšmė";case"function":return"funkcija";case"symbol":return"simbolis";case"object":return i===void 0?"nežinomas objektas":i===null?"nulinė reikšmė":Array.isArray(i)?"masyvas":Object.getPrototypeOf(i)!==Object.prototype&&i.constructor?i.constructor.name:"objektas";case"null":return"nulinė reikšmė"}return a},M=a=>a.charAt(0).toUpperCase()+a.slice(1);function de(a){const i=Math.abs(a),o=i%10,n=i%100;return n>=11&&n<=19||o===0?"many":o===1?"one":"few"}const rs=()=>{const a={string:{unit:{one:"simbolis",few:"simboliai",many:"simbolių"},verb:{smaller:{inclusive:"turi būti ne ilgesnė kaip",notInclusive:"turi būti trumpesnė kaip"},bigger:{inclusive:"turi būti ne trumpesnė kaip",notInclusive:"turi būti ilgesnė kaip"}}},file:{unit:{one:"baitas",few:"baitai",many:"baitų"},verb:{smaller:{inclusive:"turi būti ne didesnis kaip",notInclusive:"turi būti mažesnis kaip"},bigger:{inclusive:"turi būti ne mažesnis kaip",notInclusive:"turi būti didesnis kaip"}}},array:{unit:{one:"elementą",few:"elementus",many:"elementų"},verb:{smaller:{inclusive:"turi turėti ne daugiau kaip",notInclusive:"turi turėti mažiau kaip"},bigger:{inclusive:"turi turėti ne mažiau kaip",notInclusive:"turi turėti daugiau kaip"}}},set:{unit:{one:"elementą",few:"elementus",many:"elementų"},verb:{smaller:{inclusive:"turi turėti ne daugiau kaip",notInclusive:"turi turėti mažiau kaip"},bigger:{inclusive:"turi turėti ne mažiau kaip",notInclusive:"turi turėti daugiau kaip"}}}};function i(n,e,t,r){const u=a[n]??null;return u===null?u:{unit:u.unit[e],verb:u.verb[r][t?"inclusive":"notInclusive"]}}const o={regex:"įvestis",email:"el. pašto adresas",url:"URL",emoji:"jaustukas",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO data ir laikas",date:"ISO data",time:"ISO laikas",duration:"ISO trukmė",ipv4:"IPv4 adresas",ipv6:"IPv6 adresas",cidrv4:"IPv4 tinklo prefiksas (CIDR)",cidrv6:"IPv6 tinklo prefiksas (CIDR)",base64:"base64 užkoduota eilutė",base64url:"base64url užkoduota eilutė",json_string:"JSON eilutė",e164:"E.164 numeris",jwt:"JWT",template_literal:"įvestis"};return n=>{switch(n.code){case"invalid_type":return`Gautas tipas ${ts(n.input)}, o tikėtasi - ${G(n.expected)}`;case"invalid_value":return n.values.length===1?`Privalo būti ${v(n.values[0])}`:`Privalo būti vienas iš ${c(n.values,"|")} pasirinkimų`;case"too_big":{const e=G(n.origin),t=i(n.origin,de(Number(n.maximum)),n.inclusive??!1,"smaller");if(t!=null&&t.verb)return`${M(e??n.origin??"reikšmė")} ${t.verb} ${n.maximum.toString()} ${t.unit??"elementų"}`;const r=n.inclusive?"ne didesnis kaip":"mažesnis kaip";return`${M(e??n.origin??"reikšmė")} turi būti ${r} ${n.maximum.toString()} ${t==null?void 0:t.unit}`}case"too_small":{const e=G(n.origin),t=i(n.origin,de(Number(n.minimum)),n.inclusive??!1,"bigger");if(t!=null&&t.verb)return`${M(e??n.origin??"reikšmė")} ${t.verb} ${n.minimum.toString()} ${t.unit??"elementų"}`;const r=n.inclusive?"ne mažesnis kaip":"didesnis kaip";return`${M(e??n.origin??"reikšmė")} turi būti ${r} ${n.minimum.toString()} ${t==null?void 0:t.unit}`}case"invalid_format":{const e=n;return e.format==="starts_with"?`Eilutė privalo prasidėti "${e.prefix}"`:e.format==="ends_with"?`Eilutė privalo pasibaigti "${e.suffix}"`:e.format==="includes"?`Eilutė privalo įtraukti "${e.includes}"`:e.format==="regex"?`Eilutė privalo atitikti ${e.pattern}`:`Neteisingas ${o[e.format]??n.format}`}case"not_multiple_of":return`Skaičius privalo būti ${n.divisor} kartotinis.`;case"unrecognized_keys":return`Neatpažint${n.keys.length>1?"i":"as"} rakt${n.keys.length>1?"ai":"as"}: ${c(n.keys,", ")}`;case"invalid_key":return"Rastas klaidingas raktas";case"invalid_union":return"Klaidinga įvestis";case"invalid_element":{const e=G(n.origin);return`${M(e??n.origin??"reikšmė")} turi klaidingą įvestį`}default:return"Klaidinga įvestis"}}};function ns(){return{localeError:rs()}}const is=()=>{const a={string:{unit:"знаци",verb:"да имаат"},file:{unit:"бајти",verb:"да имаат"},array:{unit:"ставки",verb:"да имаат"},set:{unit:"ставки",verb:"да имаат"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"број";case"object":{if(Array.isArray(e))return"низа";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"внес",email:"адреса на е-пошта",url:"URL",emoji:"емоџи",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO датум и време",date:"ISO датум",time:"ISO време",duration:"ISO времетраење",ipv4:"IPv4 адреса",ipv6:"IPv6 адреса",cidrv4:"IPv4 опсег",cidrv6:"IPv6 опсег",base64:"base64-енкодирана низа",base64url:"base64url-енкодирана низа",json_string:"JSON низа",e164:"E.164 број",jwt:"JWT",template_literal:"внес"};return e=>{switch(e.code){case"invalid_type":return`Грешен внес: се очекува ${e.expected}, примено ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Invalid input: expected ${v(e.values[0])}`:`Грешана опција: се очекува една ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Премногу голем: се очекува ${e.origin??"вредноста"} да има ${t}${e.maximum.toString()} ${r.unit??"елементи"}`:`Премногу голем: се очекува ${e.origin??"вредноста"} да биде ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Премногу мал: се очекува ${e.origin} да има ${t}${e.minimum.toString()} ${r.unit}`:`Премногу мал: се очекува ${e.origin} да биде ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Неважечка низа: мора да започнува со "${t.prefix}"`:t.format==="ends_with"?`Неважечка низа: мора да завршува со "${t.suffix}"`:t.format==="includes"?`Неважечка низа: мора да вклучува "${t.includes}"`:t.format==="regex"?`Неважечка низа: мора да одгоара на патернот ${t.pattern}`:`Invalid ${n[t.format]??e.format}`}case"not_multiple_of":return`Грешен број: мора да биде делив со ${e.divisor}`;case"unrecognized_keys":return`${e.keys.length>1?"Непрепознаени клучеви":"Непрепознаен клуч"}: ${c(e.keys,", ")}`;case"invalid_key":return`Грешен клуч во ${e.origin}`;case"invalid_union":return"Грешен внес";case"invalid_element":return`Грешна вредност во ${e.origin}`;default:return"Грешен внес"}}};function as(){return{localeError:is()}}const os=()=>{const a={string:{unit:"aksara",verb:"mempunyai"},file:{unit:"bait",verb:"mempunyai"},array:{unit:"elemen",verb:"mempunyai"},set:{unit:"elemen",verb:"mempunyai"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"nombor";case"object":{if(Array.isArray(e))return"array";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"input",email:"alamat e-mel",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"tarikh masa ISO",date:"tarikh ISO",time:"masa ISO",duration:"tempoh ISO",ipv4:"alamat IPv4",ipv6:"alamat IPv6",cidrv4:"julat IPv4",cidrv6:"julat IPv6",base64:"string dikodkan base64",base64url:"string dikodkan base64url",json_string:"string JSON",e164:"nombor E.164",jwt:"JWT",template_literal:"input"};return e=>{switch(e.code){case"invalid_type":return`Input tidak sah: dijangka ${e.expected}, diterima ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Input tidak sah: dijangka ${v(e.values[0])}`:`Pilihan tidak sah: dijangka salah satu daripada ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Terlalu besar: dijangka ${e.origin??"nilai"} ${r.verb} ${t}${e.maximum.toString()} ${r.unit??"elemen"}`:`Terlalu besar: dijangka ${e.origin??"nilai"} adalah ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Terlalu kecil: dijangka ${e.origin} ${r.verb} ${t}${e.minimum.toString()} ${r.unit}`:`Terlalu kecil: dijangka ${e.origin} adalah ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`String tidak sah: mesti bermula dengan "${t.prefix}"`:t.format==="ends_with"?`String tidak sah: mesti berakhir dengan "${t.suffix}"`:t.format==="includes"?`String tidak sah: mesti mengandungi "${t.includes}"`:t.format==="regex"?`String tidak sah: mesti sepadan dengan corak ${t.pattern}`:`${n[t.format]??e.format} tidak sah`}case"not_multiple_of":return`Nombor tidak sah: perlu gandaan ${e.divisor}`;case"unrecognized_keys":return`Kunci tidak dikenali: ${c(e.keys,", ")}`;case"invalid_key":return`Kunci tidak sah dalam ${e.origin}`;case"invalid_union":return"Input tidak sah";case"invalid_element":return`Nilai tidak sah dalam ${e.origin}`;default:return"Input tidak sah"}}};function us(){return{localeError:os()}}const ls=()=>{const a={string:{unit:"tekens"},file:{unit:"bytes"},array:{unit:"elementen"},set:{unit:"elementen"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"getal";case"object":{if(Array.isArray(e))return"array";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"invoer",email:"emailadres",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO datum en tijd",date:"ISO datum",time:"ISO tijd",duration:"ISO duur",ipv4:"IPv4-adres",ipv6:"IPv6-adres",cidrv4:"IPv4-bereik",cidrv6:"IPv6-bereik",base64:"base64-gecodeerde tekst",base64url:"base64 URL-gecodeerde tekst",json_string:"JSON string",e164:"E.164-nummer",jwt:"JWT",template_literal:"invoer"};return e=>{switch(e.code){case"invalid_type":return`Ongeldige invoer: verwacht ${e.expected}, ontving ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Ongeldige invoer: verwacht ${v(e.values[0])}`:`Ongeldige optie: verwacht één van ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Te lang: verwacht dat ${e.origin??"waarde"} ${t}${e.maximum.toString()} ${r.unit??"elementen"} bevat`:`Te lang: verwacht dat ${e.origin??"waarde"} ${t}${e.maximum.toString()} is`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Te kort: verwacht dat ${e.origin} ${t}${e.minimum.toString()} ${r.unit} bevat`:`Te kort: verwacht dat ${e.origin} ${t}${e.minimum.toString()} is`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Ongeldige tekst: moet met "${t.prefix}" beginnen`:t.format==="ends_with"?`Ongeldige tekst: moet op "${t.suffix}" eindigen`:t.format==="includes"?`Ongeldige tekst: moet "${t.includes}" bevatten`:t.format==="regex"?`Ongeldige tekst: moet overeenkomen met patroon ${t.pattern}`:`Ongeldig: ${n[t.format]??e.format}`}case"not_multiple_of":return`Ongeldig getal: moet een veelvoud van ${e.divisor} zijn`;case"unrecognized_keys":return`Onbekende key${e.keys.length>1?"s":""}: ${c(e.keys,", ")}`;case"invalid_key":return`Ongeldige key in ${e.origin}`;case"invalid_union":return"Ongeldige invoer";case"invalid_element":return`Ongeldige waarde in ${e.origin}`;default:return"Ongeldige invoer"}}};function cs(){return{localeError:ls()}}const ss=()=>{const a={string:{unit:"tegn",verb:"å ha"},file:{unit:"bytes",verb:"å ha"},array:{unit:"elementer",verb:"å inneholde"},set:{unit:"elementer",verb:"å inneholde"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"tall";case"object":{if(Array.isArray(e))return"liste";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"input",email:"e-postadresse",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO dato- og klokkeslett",date:"ISO-dato",time:"ISO-klokkeslett",duration:"ISO-varighet",ipv4:"IPv4-område",ipv6:"IPv6-område",cidrv4:"IPv4-spekter",cidrv6:"IPv6-spekter",base64:"base64-enkodet streng",base64url:"base64url-enkodet streng",json_string:"JSON-streng",e164:"E.164-nummer",jwt:"JWT",template_literal:"input"};return e=>{switch(e.code){case"invalid_type":return`Ugyldig input: forventet ${e.expected}, fikk ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Ugyldig verdi: forventet ${v(e.values[0])}`:`Ugyldig valg: forventet en av ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`For stor(t): forventet ${e.origin??"value"} til å ha ${t}${e.maximum.toString()} ${r.unit??"elementer"}`:`For stor(t): forventet ${e.origin??"value"} til å ha ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`For lite(n): forventet ${e.origin} til å ha ${t}${e.minimum.toString()} ${r.unit}`:`For lite(n): forventet ${e.origin} til å ha ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Ugyldig streng: må starte med "${t.prefix}"`:t.format==="ends_with"?`Ugyldig streng: må ende med "${t.suffix}"`:t.format==="includes"?`Ugyldig streng: må inneholde "${t.includes}"`:t.format==="regex"?`Ugyldig streng: må matche mønsteret ${t.pattern}`:`Ugyldig ${n[t.format]??e.format}`}case"not_multiple_of":return`Ugyldig tall: må være et multiplum av ${e.divisor}`;case"unrecognized_keys":return`${e.keys.length>1?"Ukjente nøkler":"Ukjent nøkkel"}: ${c(e.keys,", ")}`;case"invalid_key":return`Ugyldig nøkkel i ${e.origin}`;case"invalid_union":return"Ugyldig input";case"invalid_element":return`Ugyldig verdi i ${e.origin}`;default:return"Ugyldig input"}}};function ds(){return{localeError:ss()}}const ms=()=>{const a={string:{unit:"harf",verb:"olmalıdır"},file:{unit:"bayt",verb:"olmalıdır"},array:{unit:"unsur",verb:"olmalıdır"},set:{unit:"unsur",verb:"olmalıdır"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"numara";case"object":{if(Array.isArray(e))return"saf";if(e===null)return"gayb";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"giren",email:"epostagâh",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO hengâmı",date:"ISO tarihi",time:"ISO zamanı",duration:"ISO müddeti",ipv4:"IPv4 nişânı",ipv6:"IPv6 nişânı",cidrv4:"IPv4 menzili",cidrv6:"IPv6 menzili",base64:"base64-şifreli metin",base64url:"base64url-şifreli metin",json_string:"JSON metin",e164:"E.164 sayısı",jwt:"JWT",template_literal:"giren"};return e=>{switch(e.code){case"invalid_type":return`Fâsit giren: umulan ${e.expected}, alınan ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Fâsit giren: umulan ${v(e.values[0])}`:`Fâsit tercih: mûteberler ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Fazla büyük: ${e.origin??"value"}, ${t}${e.maximum.toString()} ${r.unit??"elements"} sahip olmalıydı.`:`Fazla büyük: ${e.origin??"value"}, ${t}${e.maximum.toString()} olmalıydı.`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Fazla küçük: ${e.origin}, ${t}${e.minimum.toString()} ${r.unit} sahip olmalıydı.`:`Fazla küçük: ${e.origin}, ${t}${e.minimum.toString()} olmalıydı.`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Fâsit metin: "${t.prefix}" ile başlamalı.`:t.format==="ends_with"?`Fâsit metin: "${t.suffix}" ile bitmeli.`:t.format==="includes"?`Fâsit metin: "${t.includes}" ihtivâ etmeli.`:t.format==="regex"?`Fâsit metin: ${t.pattern} nakşına uymalı.`:`Fâsit ${n[t.format]??e.format}`}case"not_multiple_of":return`Fâsit sayı: ${e.divisor} katı olmalıydı.`;case"unrecognized_keys":return`Tanınmayan anahtar ${e.keys.length>1?"s":""}: ${c(e.keys,", ")}`;case"invalid_key":return`${e.origin} için tanınmayan anahtar var.`;case"invalid_union":return"Giren tanınamadı.";case"invalid_element":return`${e.origin} için tanınmayan kıymet var.`;default:return"Kıymet tanınamadı."}}};function fs(){return{localeError:ms()}}const gs=()=>{const a={string:{unit:"توکي",verb:"ولري"},file:{unit:"بایټس",verb:"ولري"},array:{unit:"توکي",verb:"ولري"},set:{unit:"توکي",verb:"ولري"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"عدد";case"object":{if(Array.isArray(e))return"ارې";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"ورودي",email:"بریښنالیک",url:"یو آر ال",emoji:"ایموجي",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"نیټه او وخت",date:"نېټه",time:"وخت",duration:"موده",ipv4:"د IPv4 پته",ipv6:"د IPv6 پته",cidrv4:"د IPv4 ساحه",cidrv6:"د IPv6 ساحه",base64:"base64-encoded متن",base64url:"base64url-encoded متن",json_string:"JSON متن",e164:"د E.164 شمېره",jwt:"JWT",template_literal:"ورودي"};return e=>{switch(e.code){case"invalid_type":return`ناسم ورودي: باید ${e.expected} وای, مګر ${o(e.input)} ترلاسه شو`;case"invalid_value":return e.values.length===1?`ناسم ورودي: باید ${v(e.values[0])} وای`:`ناسم انتخاب: باید یو له ${c(e.values,"|")} څخه وای`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`ډیر لوی: ${e.origin??"ارزښت"} باید ${t}${e.maximum.toString()} ${r.unit??"عنصرونه"} ولري`:`ډیر لوی: ${e.origin??"ارزښت"} باید ${t}${e.maximum.toString()} وي`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`ډیر کوچنی: ${e.origin} باید ${t}${e.minimum.toString()} ${r.unit} ولري`:`ډیر کوچنی: ${e.origin} باید ${t}${e.minimum.toString()} وي`}case"invalid_format":{const t=e;return t.format==="starts_with"?`ناسم متن: باید د "${t.prefix}" سره پیل شي`:t.format==="ends_with"?`ناسم متن: باید د "${t.suffix}" سره پای ته ورسيږي`:t.format==="includes"?`ناسم متن: باید "${t.includes}" ولري`:t.format==="regex"?`ناسم متن: باید د ${t.pattern} سره مطابقت ولري`:`${n[t.format]??e.format} ناسم دی`}case"not_multiple_of":return`ناسم عدد: باید د ${e.divisor} مضرب وي`;case"unrecognized_keys":return`ناسم ${e.keys.length>1?"کلیډونه":"کلیډ"}: ${c(e.keys,", ")}`;case"invalid_key":return`ناسم کلیډ په ${e.origin} کې`;case"invalid_union":return"ناسمه ورودي";case"invalid_element":return`ناسم عنصر په ${e.origin} کې`;default:return"ناسمه ورودي"}}};function vs(){return{localeError:gs()}}const ps=()=>{const a={string:{unit:"znaków",verb:"mieć"},file:{unit:"bajtów",verb:"mieć"},array:{unit:"elementów",verb:"mieć"},set:{unit:"elementów",verb:"mieć"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"liczba";case"object":{if(Array.isArray(e))return"tablica";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"wyrażenie",email:"adres email",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"data i godzina w formacie ISO",date:"data w formacie ISO",time:"godzina w formacie ISO",duration:"czas trwania ISO",ipv4:"adres IPv4",ipv6:"adres IPv6",cidrv4:"zakres IPv4",cidrv6:"zakres IPv6",base64:"ciąg znaków zakodowany w formacie base64",base64url:"ciąg znaków zakodowany w formacie base64url",json_string:"ciąg znaków w formacie JSON",e164:"liczba E.164",jwt:"JWT",template_literal:"wejście"};return e=>{switch(e.code){case"invalid_type":return`Nieprawidłowe dane wejściowe: oczekiwano ${e.expected}, otrzymano ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Nieprawidłowe dane wejściowe: oczekiwano ${v(e.values[0])}`:`Nieprawidłowa opcja: oczekiwano jednej z wartości ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Za duża wartość: oczekiwano, że ${e.origin??"wartość"} będzie mieć ${t}${e.maximum.toString()} ${r.unit??"elementów"}`:`Zbyt duż(y/a/e): oczekiwano, że ${e.origin??"wartość"} będzie wynosić ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Za mała wartość: oczekiwano, że ${e.origin??"wartość"} będzie mieć ${t}${e.minimum.toString()} ${r.unit??"elementów"}`:`Zbyt mał(y/a/e): oczekiwano, że ${e.origin??"wartość"} będzie wynosić ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Nieprawidłowy ciąg znaków: musi zaczynać się od "${t.prefix}"`:t.format==="ends_with"?`Nieprawidłowy ciąg znaków: musi kończyć się na "${t.suffix}"`:t.format==="includes"?`Nieprawidłowy ciąg znaków: musi zawierać "${t.includes}"`:t.format==="regex"?`Nieprawidłowy ciąg znaków: musi odpowiadać wzorcowi ${t.pattern}`:`Nieprawidłow(y/a/e) ${n[t.format]??e.format}`}case"not_multiple_of":return`Nieprawidłowa liczba: musi być wielokrotnością ${e.divisor}`;case"unrecognized_keys":return`Nierozpoznane klucze${e.keys.length>1?"s":""}: ${c(e.keys,", ")}`;case"invalid_key":return`Nieprawidłowy klucz w ${e.origin}`;case"invalid_union":return"Nieprawidłowe dane wejściowe";case"invalid_element":return`Nieprawidłowa wartość w ${e.origin}`;default:return"Nieprawidłowe dane wejściowe"}}};function $s(){return{localeError:ps()}}const bs=()=>{const a={string:{unit:"caracteres",verb:"ter"},file:{unit:"bytes",verb:"ter"},array:{unit:"itens",verb:"ter"},set:{unit:"itens",verb:"ter"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"número";case"object":{if(Array.isArray(e))return"array";if(e===null)return"nulo";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"padrão",email:"endereço de e-mail",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"data e hora ISO",date:"data ISO",time:"hora ISO",duration:"duração ISO",ipv4:"endereço IPv4",ipv6:"endereço IPv6",cidrv4:"faixa de IPv4",cidrv6:"faixa de IPv6",base64:"texto codificado em base64",base64url:"URL codificada em base64",json_string:"texto JSON",e164:"número E.164",jwt:"JWT",template_literal:"entrada"};return e=>{switch(e.code){case"invalid_type":return`Tipo inválido: esperado ${e.expected}, recebido ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Entrada inválida: esperado ${v(e.values[0])}`:`Opção inválida: esperada uma das ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Muito grande: esperado que ${e.origin??"valor"} tivesse ${t}${e.maximum.toString()} ${r.unit??"elementos"}`:`Muito grande: esperado que ${e.origin??"valor"} fosse ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Muito pequeno: esperado que ${e.origin} tivesse ${t}${e.minimum.toString()} ${r.unit}`:`Muito pequeno: esperado que ${e.origin} fosse ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Texto inválido: deve começar com "${t.prefix}"`:t.format==="ends_with"?`Texto inválido: deve terminar com "${t.suffix}"`:t.format==="includes"?`Texto inválido: deve incluir "${t.includes}"`:t.format==="regex"?`Texto inválido: deve corresponder ao padrão ${t.pattern}`:`${n[t.format]??e.format} inválido`}case"not_multiple_of":return`Número inválido: deve ser múltiplo de ${e.divisor}`;case"unrecognized_keys":return`Chave${e.keys.length>1?"s":""} desconhecida${e.keys.length>1?"s":""}: ${c(e.keys,", ")}`;case"invalid_key":return`Chave inválida em ${e.origin}`;case"invalid_union":return"Entrada inválida";case"invalid_element":return`Valor inválido em ${e.origin}`;default:return"Campo inválido"}}};function ys(){return{localeError:bs()}}function me(a,i,o,n){const e=Math.abs(a),t=e%10,r=e%100;return r>=11&&r<=19?n:t===1?i:t>=2&&t<=4?o:n}const hs=()=>{const a={string:{unit:{one:"символ",few:"символа",many:"символов"},verb:"иметь"},file:{unit:{one:"байт",few:"байта",many:"байт"},verb:"иметь"},array:{unit:{one:"элемент",few:"элемента",many:"элементов"},verb:"иметь"},set:{unit:{one:"элемент",few:"элемента",many:"элементов"},verb:"иметь"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"число";case"object":{if(Array.isArray(e))return"массив";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"ввод",email:"email адрес",url:"URL",emoji:"эмодзи",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO дата и время",date:"ISO дата",time:"ISO время",duration:"ISO длительность",ipv4:"IPv4 адрес",ipv6:"IPv6 адрес",cidrv4:"IPv4 диапазон",cidrv6:"IPv6 диапазон",base64:"строка в формате base64",base64url:"строка в формате base64url",json_string:"JSON строка",e164:"номер E.164",jwt:"JWT",template_literal:"ввод"};return e=>{switch(e.code){case"invalid_type":return`Неверный ввод: ожидалось ${e.expected}, получено ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Неверный ввод: ожидалось ${v(e.values[0])}`:`Неверный вариант: ожидалось одно из ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);if(r){const u=Number(e.maximum),d=me(u,r.unit.one,r.unit.few,r.unit.many);return`Слишком большое значение: ожидалось, что ${e.origin??"значение"} будет иметь ${t}${e.maximum.toString()} ${d}`}return`Слишком большое значение: ожидалось, что ${e.origin??"значение"} будет ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);if(r){const u=Number(e.minimum),d=me(u,r.unit.one,r.unit.few,r.unit.many);return`Слишком маленькое значение: ожидалось, что ${e.origin} будет иметь ${t}${e.minimum.toString()} ${d}`}return`Слишком маленькое значение: ожидалось, что ${e.origin} будет ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Неверная строка: должна начинаться с "${t.prefix}"`:t.format==="ends_with"?`Неверная строка: должна заканчиваться на "${t.suffix}"`:t.format==="includes"?`Неверная строка: должна содержать "${t.includes}"`:t.format==="regex"?`Неверная строка: должна соответствовать шаблону ${t.pattern}`:`Неверный ${n[t.format]??e.format}`}case"not_multiple_of":return`Неверное число: должно быть кратным ${e.divisor}`;case"unrecognized_keys":return`Нераспознанн${e.keys.length>1?"ые":"ый"} ключ${e.keys.length>1?"и":""}: ${c(e.keys,", ")}`;case"invalid_key":return`Неверный ключ в ${e.origin}`;case"invalid_union":return"Неверные входные данные";case"invalid_element":return`Неверное значение в ${e.origin}`;default:return"Неверные входные данные"}}};function _s(){return{localeError:hs()}}const ks=()=>{const a={string:{unit:"znakov",verb:"imeti"},file:{unit:"bajtov",verb:"imeti"},array:{unit:"elementov",verb:"imeti"},set:{unit:"elementov",verb:"imeti"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"število";case"object":{if(Array.isArray(e))return"tabela";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"vnos",email:"e-poštni naslov",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO datum in čas",date:"ISO datum",time:"ISO čas",duration:"ISO trajanje",ipv4:"IPv4 naslov",ipv6:"IPv6 naslov",cidrv4:"obseg IPv4",cidrv6:"obseg IPv6",base64:"base64 kodiran niz",base64url:"base64url kodiran niz",json_string:"JSON niz",e164:"E.164 številka",jwt:"JWT",template_literal:"vnos"};return e=>{switch(e.code){case"invalid_type":return`Neveljaven vnos: pričakovano ${e.expected}, prejeto ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Neveljaven vnos: pričakovano ${v(e.values[0])}`:`Neveljavna možnost: pričakovano eno izmed ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Preveliko: pričakovano, da bo ${e.origin??"vrednost"} imelo ${t}${e.maximum.toString()} ${r.unit??"elementov"}`:`Preveliko: pričakovano, da bo ${e.origin??"vrednost"} ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Premajhno: pričakovano, da bo ${e.origin} imelo ${t}${e.minimum.toString()} ${r.unit}`:`Premajhno: pričakovano, da bo ${e.origin} ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Neveljaven niz: mora se začeti z "${t.prefix}"`:t.format==="ends_with"?`Neveljaven niz: mora se končati z "${t.suffix}"`:t.format==="includes"?`Neveljaven niz: mora vsebovati "${t.includes}"`:t.format==="regex"?`Neveljaven niz: mora ustrezati vzorcu ${t.pattern}`:`Neveljaven ${n[t.format]??e.format}`}case"not_multiple_of":return`Neveljavno število: mora biti večkratnik ${e.divisor}`;case"unrecognized_keys":return`Neprepoznan${e.keys.length>1?"i ključi":" ključ"}: ${c(e.keys,", ")}`;case"invalid_key":return`Neveljaven ključ v ${e.origin}`;case"invalid_union":return"Neveljaven vnos";case"invalid_element":return`Neveljavna vrednost v ${e.origin}`;default:return"Neveljaven vnos"}}};function Is(){return{localeError:ks()}}const Ss=()=>{const a={string:{unit:"tecken",verb:"att ha"},file:{unit:"bytes",verb:"att ha"},array:{unit:"objekt",verb:"att innehålla"},set:{unit:"objekt",verb:"att innehålla"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"antal";case"object":{if(Array.isArray(e))return"lista";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"reguljärt uttryck",email:"e-postadress",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO-datum och tid",date:"ISO-datum",time:"ISO-tid",duration:"ISO-varaktighet",ipv4:"IPv4-intervall",ipv6:"IPv6-intervall",cidrv4:"IPv4-spektrum",cidrv6:"IPv6-spektrum",base64:"base64-kodad sträng",base64url:"base64url-kodad sträng",json_string:"JSON-sträng",e164:"E.164-nummer",jwt:"JWT",template_literal:"mall-literal"};return e=>{switch(e.code){case"invalid_type":return`Ogiltig inmatning: förväntat ${e.expected}, fick ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Ogiltig inmatning: förväntat ${v(e.values[0])}`:`Ogiltigt val: förväntade en av ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`För stor(t): förväntade ${e.origin??"värdet"} att ha ${t}${e.maximum.toString()} ${r.unit??"element"}`:`För stor(t): förväntat ${e.origin??"värdet"} att ha ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`För lite(t): förväntade ${e.origin??"värdet"} att ha ${t}${e.minimum.toString()} ${r.unit}`:`För lite(t): förväntade ${e.origin??"värdet"} att ha ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Ogiltig sträng: måste börja med "${t.prefix}"`:t.format==="ends_with"?`Ogiltig sträng: måste sluta med "${t.suffix}"`:t.format==="includes"?`Ogiltig sträng: måste innehålla "${t.includes}"`:t.format==="regex"?`Ogiltig sträng: måste matcha mönstret "${t.pattern}"`:`Ogiltig(t) ${n[t.format]??e.format}`}case"not_multiple_of":return`Ogiltigt tal: måste vara en multipel av ${e.divisor}`;case"unrecognized_keys":return`${e.keys.length>1?"Okända nycklar":"Okänd nyckel"}: ${c(e.keys,", ")}`;case"invalid_key":return`Ogiltig nyckel i ${e.origin??"värdet"}`;case"invalid_union":return"Ogiltig input";case"invalid_element":return`Ogiltigt värde i ${e.origin??"värdet"}`;default:return"Ogiltig input"}}};function js(){return{localeError:Ss()}}const xs=()=>{const a={string:{unit:"எழுத்துக்கள்",verb:"கொண்டிருக்க வேண்டும்"},file:{unit:"பைட்டுகள்",verb:"கொண்டிருக்க வேண்டும்"},array:{unit:"உறுப்புகள்",verb:"கொண்டிருக்க வேண்டும்"},set:{unit:"உறுப்புகள்",verb:"கொண்டிருக்க வேண்டும்"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"எண் அல்லாதது":"எண்";case"object":{if(Array.isArray(e))return"அணி";if(e===null)return"வெறுமை";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"உள்ளீடு",email:"மின்னஞ்சல் முகவரி",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO தேதி நேரம்",date:"ISO தேதி",time:"ISO நேரம்",duration:"ISO கால அளவு",ipv4:"IPv4 முகவரி",ipv6:"IPv6 முகவரி",cidrv4:"IPv4 வரம்பு",cidrv6:"IPv6 வரம்பு",base64:"base64-encoded சரம்",base64url:"base64url-encoded சரம்",json_string:"JSON சரம்",e164:"E.164 எண்",jwt:"JWT",template_literal:"input"};return e=>{switch(e.code){case"invalid_type":return`தவறான உள்ளீடு: எதிர்பார்க்கப்பட்டது ${e.expected}, பெறப்பட்டது ${o(e.input)}`;case"invalid_value":return e.values.length===1?`தவறான உள்ளீடு: எதிர்பார்க்கப்பட்டது ${v(e.values[0])}`:`தவறான விருப்பம்: எதிர்பார்க்கப்பட்டது ${c(e.values,"|")} இல் ஒன்று`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`மிக பெரியது: எதிர்பார்க்கப்பட்டது ${e.origin??"மதிப்பு"} ${t}${e.maximum.toString()} ${r.unit??"உறுப்புகள்"} ஆக இருக்க வேண்டும்`:`மிக பெரியது: எதிர்பார்க்கப்பட்டது ${e.origin??"மதிப்பு"} ${t}${e.maximum.toString()} ஆக இருக்க வேண்டும்`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`மிகச் சிறியது: எதிர்பார்க்கப்பட்டது ${e.origin} ${t}${e.minimum.toString()} ${r.unit} ஆக இருக்க வேண்டும்`:`மிகச் சிறியது: எதிர்பார்க்கப்பட்டது ${e.origin} ${t}${e.minimum.toString()} ஆக இருக்க வேண்டும்`}case"invalid_format":{const t=e;return t.format==="starts_with"?`தவறான சரம்: "${t.prefix}" இல் தொடங்க வேண்டும்`:t.format==="ends_with"?`தவறான சரம்: "${t.suffix}" இல் முடிவடைய வேண்டும்`:t.format==="includes"?`தவறான சரம்: "${t.includes}" ஐ உள்ளடக்க வேண்டும்`:t.format==="regex"?`தவறான சரம்: ${t.pattern} முறைபாட்டுடன் பொருந்த வேண்டும்`:`தவறான ${n[t.format]??e.format}`}case"not_multiple_of":return`தவறான எண்: ${e.divisor} இன் பலமாக இருக்க வேண்டும்`;case"unrecognized_keys":return`அடையாளம் தெரியாத விசை${e.keys.length>1?"கள்":""}: ${c(e.keys,", ")}`;case"invalid_key":return`${e.origin} இல் தவறான விசை`;case"invalid_union":return"தவறான உள்ளீடு";case"invalid_element":return`${e.origin} இல் தவறான மதிப்பு`;default:return"தவறான உள்ளீடு"}}};function Us(){return{localeError:xs()}}const Os=()=>{const a={string:{unit:"ตัวอักษร",verb:"ควรมี"},file:{unit:"ไบต์",verb:"ควรมี"},array:{unit:"รายการ",verb:"ควรมี"},set:{unit:"รายการ",verb:"ควรมี"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"ไม่ใช่ตัวเลข (NaN)":"ตัวเลข";case"object":{if(Array.isArray(e))return"อาร์เรย์ (Array)";if(e===null)return"ไม่มีค่า (null)";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"ข้อมูลที่ป้อน",email:"ที่อยู่อีเมล",url:"URL",emoji:"อิโมจิ",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"วันที่เวลาแบบ ISO",date:"วันที่แบบ ISO",time:"เวลาแบบ ISO",duration:"ช่วงเวลาแบบ ISO",ipv4:"ที่อยู่ IPv4",ipv6:"ที่อยู่ IPv6",cidrv4:"ช่วง IP แบบ IPv4",cidrv6:"ช่วง IP แบบ IPv6",base64:"ข้อความแบบ Base64",base64url:"ข้อความแบบ Base64 สำหรับ URL",json_string:"ข้อความแบบ JSON",e164:"เบอร์โทรศัพท์ระหว่างประเทศ (E.164)",jwt:"โทเคน JWT",template_literal:"ข้อมูลที่ป้อน"};return e=>{switch(e.code){case"invalid_type":return`ประเภทข้อมูลไม่ถูกต้อง: ควรเป็น ${e.expected} แต่ได้รับ ${o(e.input)}`;case"invalid_value":return e.values.length===1?`ค่าไม่ถูกต้อง: ควรเป็น ${v(e.values[0])}`:`ตัวเลือกไม่ถูกต้อง: ควรเป็นหนึ่งใน ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"ไม่เกิน":"น้อยกว่า",r=i(e.origin);return r?`เกินกำหนด: ${e.origin??"ค่า"} ควรมี${t} ${e.maximum.toString()} ${r.unit??"รายการ"}`:`เกินกำหนด: ${e.origin??"ค่า"} ควรมี${t} ${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?"อย่างน้อย":"มากกว่า",r=i(e.origin);return r?`น้อยกว่ากำหนด: ${e.origin} ควรมี${t} ${e.minimum.toString()} ${r.unit}`:`น้อยกว่ากำหนด: ${e.origin} ควรมี${t} ${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`รูปแบบไม่ถูกต้อง: ข้อความต้องขึ้นต้นด้วย "${t.prefix}"`:t.format==="ends_with"?`รูปแบบไม่ถูกต้อง: ข้อความต้องลงท้ายด้วย "${t.suffix}"`:t.format==="includes"?`รูปแบบไม่ถูกต้อง: ข้อความต้องมี "${t.includes}" อยู่ในข้อความ`:t.format==="regex"?`รูปแบบไม่ถูกต้อง: ต้องตรงกับรูปแบบที่กำหนด ${t.pattern}`:`รูปแบบไม่ถูกต้อง: ${n[t.format]??e.format}`}case"not_multiple_of":return`ตัวเลขไม่ถูกต้อง: ต้องเป็นจำนวนที่หารด้วย ${e.divisor} ได้ลงตัว`;case"unrecognized_keys":return`พบคีย์ที่ไม่รู้จัก: ${c(e.keys,", ")}`;case"invalid_key":return`คีย์ไม่ถูกต้องใน ${e.origin}`;case"invalid_union":return"ข้อมูลไม่ถูกต้อง: ไม่ตรงกับรูปแบบยูเนียนที่กำหนดไว้";case"invalid_element":return`ข้อมูลไม่ถูกต้องใน ${e.origin}`;default:return"ข้อมูลไม่ถูกต้อง"}}};function ws(){return{localeError:Os()}}const Ns=a=>{const i=typeof a;switch(i){case"number":return Number.isNaN(a)?"NaN":"number";case"object":{if(Array.isArray(a))return"array";if(a===null)return"null";if(Object.getPrototypeOf(a)!==Object.prototype&&a.constructor)return a.constructor.name}}return i},zs=()=>{const a={string:{unit:"karakter",verb:"olmalı"},file:{unit:"bayt",verb:"olmalı"},array:{unit:"öğe",verb:"olmalı"},set:{unit:"öğe",verb:"olmalı"}};function i(n){return a[n]??null}const o={regex:"girdi",email:"e-posta adresi",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO tarih ve saat",date:"ISO tarih",time:"ISO saat",duration:"ISO süre",ipv4:"IPv4 adresi",ipv6:"IPv6 adresi",cidrv4:"IPv4 aralığı",cidrv6:"IPv6 aralığı",base64:"base64 ile şifrelenmiş metin",base64url:"base64url ile şifrelenmiş metin",json_string:"JSON dizesi",e164:"E.164 sayısı",jwt:"JWT",template_literal:"Şablon dizesi"};return n=>{switch(n.code){case"invalid_type":return`Geçersiz değer: beklenen ${n.expected}, alınan ${Ns(n.input)}`;case"invalid_value":return n.values.length===1?`Geçersiz değer: beklenen ${v(n.values[0])}`:`Geçersiz seçenek: aşağıdakilerden biri olmalı: ${c(n.values,"|")}`;case"too_big":{const e=n.inclusive?"<=":"<",t=i(n.origin);return t?`Çok büyük: beklenen ${n.origin??"değer"} ${e}${n.maximum.toString()} ${t.unit??"öğe"}`:`Çok büyük: beklenen ${n.origin??"değer"} ${e}${n.maximum.toString()}`}case"too_small":{const e=n.inclusive?">=":">",t=i(n.origin);return t?`Çok küçük: beklenen ${n.origin} ${e}${n.minimum.toString()} ${t.unit}`:`Çok küçük: beklenen ${n.origin} ${e}${n.minimum.toString()}`}case"invalid_format":{const e=n;return e.format==="starts_with"?`Geçersiz metin: "${e.prefix}" ile başlamalı`:e.format==="ends_with"?`Geçersiz metin: "${e.suffix}" ile bitmeli`:e.format==="includes"?`Geçersiz metin: "${e.includes}" içermeli`:e.format==="regex"?`Geçersiz metin: ${e.pattern} desenine uymalı`:`Geçersiz ${o[e.format]??n.format}`}case"not_multiple_of":return`Geçersiz sayı: ${n.divisor} ile tam bölünebilmeli`;case"unrecognized_keys":return`Tanınmayan anahtar${n.keys.length>1?"lar":""}: ${c(n.keys,", ")}`;case"invalid_key":return`${n.origin} içinde geçersiz anahtar`;case"invalid_union":return"Geçersiz değer";case"invalid_element":return`${n.origin} içinde geçersiz değer`;default:return"Geçersiz değer"}}};function Ds(){return{localeError:zs()}}const Ps=()=>{const a={string:{unit:"символів",verb:"матиме"},file:{unit:"байтів",verb:"матиме"},array:{unit:"елементів",verb:"матиме"},set:{unit:"елементів",verb:"матиме"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"число";case"object":{if(Array.isArray(e))return"масив";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"вхідні дані",email:"адреса електронної пошти",url:"URL",emoji:"емодзі",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"дата та час ISO",date:"дата ISO",time:"час ISO",duration:"тривалість ISO",ipv4:"адреса IPv4",ipv6:"адреса IPv6",cidrv4:"діапазон IPv4",cidrv6:"діапазон IPv6",base64:"рядок у кодуванні base64",base64url:"рядок у кодуванні base64url",json_string:"рядок JSON",e164:"номер E.164",jwt:"JWT",template_literal:"вхідні дані"};return e=>{switch(e.code){case"invalid_type":return`Неправильні вхідні дані: очікується ${e.expected}, отримано ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Неправильні вхідні дані: очікується ${v(e.values[0])}`:`Неправильна опція: очікується одне з ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Занадто велике: очікується, що ${e.origin??"значення"} ${r.verb} ${t}${e.maximum.toString()} ${r.unit??"елементів"}`:`Занадто велике: очікується, що ${e.origin??"значення"} буде ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Занадто мале: очікується, що ${e.origin} ${r.verb} ${t}${e.minimum.toString()} ${r.unit}`:`Занадто мале: очікується, що ${e.origin} буде ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Неправильний рядок: повинен починатися з "${t.prefix}"`:t.format==="ends_with"?`Неправильний рядок: повинен закінчуватися на "${t.suffix}"`:t.format==="includes"?`Неправильний рядок: повинен містити "${t.includes}"`:t.format==="regex"?`Неправильний рядок: повинен відповідати шаблону ${t.pattern}`:`Неправильний ${n[t.format]??e.format}`}case"not_multiple_of":return`Неправильне число: повинно бути кратним ${e.divisor}`;case"unrecognized_keys":return`Нерозпізнаний ключ${e.keys.length>1?"і":""}: ${c(e.keys,", ")}`;case"invalid_key":return`Неправильний ключ у ${e.origin}`;case"invalid_union":return"Неправильні вхідні дані";case"invalid_element":return`Неправильне значення у ${e.origin}`;default:return"Неправильні вхідні дані"}}};function It(){return{localeError:Ps()}}function Ts(){return It()}const Es=()=>{const a={string:{unit:"حروف",verb:"ہونا"},file:{unit:"بائٹس",verb:"ہونا"},array:{unit:"آئٹمز",verb:"ہونا"},set:{unit:"آئٹمز",verb:"ہونا"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"نمبر";case"object":{if(Array.isArray(e))return"آرے";if(e===null)return"نل";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"ان پٹ",email:"ای میل ایڈریس",url:"یو آر ایل",emoji:"ایموجی",uuid:"یو یو آئی ڈی",uuidv4:"یو یو آئی ڈی وی 4",uuidv6:"یو یو آئی ڈی وی 6",nanoid:"نینو آئی ڈی",guid:"جی یو آئی ڈی",cuid:"سی یو آئی ڈی",cuid2:"سی یو آئی ڈی 2",ulid:"یو ایل آئی ڈی",xid:"ایکس آئی ڈی",ksuid:"کے ایس یو آئی ڈی",datetime:"آئی ایس او ڈیٹ ٹائم",date:"آئی ایس او تاریخ",time:"آئی ایس او وقت",duration:"آئی ایس او مدت",ipv4:"آئی پی وی 4 ایڈریس",ipv6:"آئی پی وی 6 ایڈریس",cidrv4:"آئی پی وی 4 رینج",cidrv6:"آئی پی وی 6 رینج",base64:"بیس 64 ان کوڈڈ سٹرنگ",base64url:"بیس 64 یو آر ایل ان کوڈڈ سٹرنگ",json_string:"جے ایس او این سٹرنگ",e164:"ای 164 نمبر",jwt:"جے ڈبلیو ٹی",template_literal:"ان پٹ"};return e=>{switch(e.code){case"invalid_type":return`غلط ان پٹ: ${e.expected} متوقع تھا، ${o(e.input)} موصول ہوا`;case"invalid_value":return e.values.length===1?`غلط ان پٹ: ${v(e.values[0])} متوقع تھا`:`غلط آپشن: ${c(e.values,"|")} میں سے ایک متوقع تھا`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`بہت بڑا: ${e.origin??"ویلیو"} کے ${t}${e.maximum.toString()} ${r.unit??"عناصر"} ہونے متوقع تھے`:`بہت بڑا: ${e.origin??"ویلیو"} کا ${t}${e.maximum.toString()} ہونا متوقع تھا`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`بہت چھوٹا: ${e.origin} کے ${t}${e.minimum.toString()} ${r.unit} ہونے متوقع تھے`:`بہت چھوٹا: ${e.origin} کا ${t}${e.minimum.toString()} ہونا متوقع تھا`}case"invalid_format":{const t=e;return t.format==="starts_with"?`غلط سٹرنگ: "${t.prefix}" سے شروع ہونا چاہیے`:t.format==="ends_with"?`غلط سٹرنگ: "${t.suffix}" پر ختم ہونا چاہیے`:t.format==="includes"?`غلط سٹرنگ: "${t.includes}" شامل ہونا چاہیے`:t.format==="regex"?`غلط سٹرنگ: پیٹرن ${t.pattern} سے میچ ہونا چاہیے`:`غلط ${n[t.format]??e.format}`}case"not_multiple_of":return`غلط نمبر: ${e.divisor} کا مضاعف ہونا چاہیے`;case"unrecognized_keys":return`غیر تسلیم شدہ کی${e.keys.length>1?"ز":""}: ${c(e.keys,"، ")}`;case"invalid_key":return`${e.origin} میں غلط کی`;case"invalid_union":return"غلط ان پٹ";case"invalid_element":return`${e.origin} میں غلط ویلیو`;default:return"غلط ان پٹ"}}};function As(){return{localeError:Es()}}const Zs=()=>{const a={string:{unit:"ký tự",verb:"có"},file:{unit:"byte",verb:"có"},array:{unit:"phần tử",verb:"có"},set:{unit:"phần tử",verb:"có"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"số";case"object":{if(Array.isArray(e))return"mảng";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"đầu vào",email:"địa chỉ email",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ngày giờ ISO",date:"ngày ISO",time:"giờ ISO",duration:"khoảng thời gian ISO",ipv4:"địa chỉ IPv4",ipv6:"địa chỉ IPv6",cidrv4:"dải IPv4",cidrv6:"dải IPv6",base64:"chuỗi mã hóa base64",base64url:"chuỗi mã hóa base64url",json_string:"chuỗi JSON",e164:"số E.164",jwt:"JWT",template_literal:"đầu vào"};return e=>{switch(e.code){case"invalid_type":return`Đầu vào không hợp lệ: mong đợi ${e.expected}, nhận được ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Đầu vào không hợp lệ: mong đợi ${v(e.values[0])}`:`Tùy chọn không hợp lệ: mong đợi một trong các giá trị ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Quá lớn: mong đợi ${e.origin??"giá trị"} ${r.verb} ${t}${e.maximum.toString()} ${r.unit??"phần tử"}`:`Quá lớn: mong đợi ${e.origin??"giá trị"} ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Quá nhỏ: mong đợi ${e.origin} ${r.verb} ${t}${e.minimum.toString()} ${r.unit}`:`Quá nhỏ: mong đợi ${e.origin} ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Chuỗi không hợp lệ: phải bắt đầu bằng "${t.prefix}"`:t.format==="ends_with"?`Chuỗi không hợp lệ: phải kết thúc bằng "${t.suffix}"`:t.format==="includes"?`Chuỗi không hợp lệ: phải bao gồm "${t.includes}"`:t.format==="regex"?`Chuỗi không hợp lệ: phải khớp với mẫu ${t.pattern}`:`${n[t.format]??e.format} không hợp lệ`}case"not_multiple_of":return`Số không hợp lệ: phải là bội số của ${e.divisor}`;case"unrecognized_keys":return`Khóa không được nhận dạng: ${c(e.keys,", ")}`;case"invalid_key":return`Khóa không hợp lệ trong ${e.origin}`;case"invalid_union":return"Đầu vào không hợp lệ";case"invalid_element":return`Giá trị không hợp lệ trong ${e.origin}`;default:return"Đầu vào không hợp lệ"}}};function Cs(){return{localeError:Zs()}}const Ls=()=>{const a={string:{unit:"字符",verb:"包含"},file:{unit:"字节",verb:"包含"},array:{unit:"项",verb:"包含"},set:{unit:"项",verb:"包含"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"非数字(NaN)":"数字";case"object":{if(Array.isArray(e))return"数组";if(e===null)return"空值(null)";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"输入",email:"电子邮件",url:"URL",emoji:"表情符号",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO日期时间",date:"ISO日期",time:"ISO时间",duration:"ISO时长",ipv4:"IPv4地址",ipv6:"IPv6地址",cidrv4:"IPv4网段",cidrv6:"IPv6网段",base64:"base64编码字符串",base64url:"base64url编码字符串",json_string:"JSON字符串",e164:"E.164号码",jwt:"JWT",template_literal:"输入"};return e=>{switch(e.code){case"invalid_type":return`无效输入：期望 ${e.expected}，实际接收 ${o(e.input)}`;case"invalid_value":return e.values.length===1?`无效输入：期望 ${v(e.values[0])}`:`无效选项：期望以下之一 ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`数值过大：期望 ${e.origin??"值"} ${t}${e.maximum.toString()} ${r.unit??"个元素"}`:`数值过大：期望 ${e.origin??"值"} ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`数值过小：期望 ${e.origin} ${t}${e.minimum.toString()} ${r.unit}`:`数值过小：期望 ${e.origin} ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`无效字符串：必须以 "${t.prefix}" 开头`:t.format==="ends_with"?`无效字符串：必须以 "${t.suffix}" 结尾`:t.format==="includes"?`无效字符串：必须包含 "${t.includes}"`:t.format==="regex"?`无效字符串：必须满足正则表达式 ${t.pattern}`:`无效${n[t.format]??e.format}`}case"not_multiple_of":return`无效数字：必须是 ${e.divisor} 的倍数`;case"unrecognized_keys":return`出现未知的键(key): ${c(e.keys,", ")}`;case"invalid_key":return`${e.origin} 中的键(key)无效`;case"invalid_union":return"无效输入";case"invalid_element":return`${e.origin} 中包含无效值(value)`;default:return"无效输入"}}};function Rs(){return{localeError:Ls()}}const Js=()=>{const a={string:{unit:"字元",verb:"擁有"},file:{unit:"位元組",verb:"擁有"},array:{unit:"項目",verb:"擁有"},set:{unit:"項目",verb:"擁有"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"number";case"object":{if(Array.isArray(e))return"array";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"輸入",email:"郵件地址",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO 日期時間",date:"ISO 日期",time:"ISO 時間",duration:"ISO 期間",ipv4:"IPv4 位址",ipv6:"IPv6 位址",cidrv4:"IPv4 範圍",cidrv6:"IPv6 範圍",base64:"base64 編碼字串",base64url:"base64url 編碼字串",json_string:"JSON 字串",e164:"E.164 數值",jwt:"JWT",template_literal:"輸入"};return e=>{switch(e.code){case"invalid_type":return`無效的輸入值：預期為 ${e.expected}，但收到 ${o(e.input)}`;case"invalid_value":return e.values.length===1?`無效的輸入值：預期為 ${v(e.values[0])}`:`無效的選項：預期為以下其中之一 ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`數值過大：預期 ${e.origin??"值"} 應為 ${t}${e.maximum.toString()} ${r.unit??"個元素"}`:`數值過大：預期 ${e.origin??"值"} 應為 ${t}${e.maximum.toString()}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`數值過小：預期 ${e.origin} 應為 ${t}${e.minimum.toString()} ${r.unit}`:`數值過小：預期 ${e.origin} 應為 ${t}${e.minimum.toString()}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`無效的字串：必須以 "${t.prefix}" 開頭`:t.format==="ends_with"?`無效的字串：必須以 "${t.suffix}" 結尾`:t.format==="includes"?`無效的字串：必須包含 "${t.includes}"`:t.format==="regex"?`無效的字串：必須符合格式 ${t.pattern}`:`無效的 ${n[t.format]??e.format}`}case"not_multiple_of":return`無效的數字：必須為 ${e.divisor} 的倍數`;case"unrecognized_keys":return`無法識別的鍵值${e.keys.length>1?"們":""}：${c(e.keys,"、")}`;case"invalid_key":return`${e.origin} 中有無效的鍵值`;case"invalid_union":return"無效的輸入值";case"invalid_element":return`${e.origin} 中有無效的值`;default:return"無效的輸入值"}}};function Fs(){return{localeError:Js()}}const Ms=()=>{const a={string:{unit:"àmi",verb:"ní"},file:{unit:"bytes",verb:"ní"},array:{unit:"nkan",verb:"ní"},set:{unit:"nkan",verb:"ní"}};function i(e){return a[e]??null}const o=e=>{const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":"nọ́mbà";case"object":{if(Array.isArray(e))return"akopọ";if(e===null)return"null";if(Object.getPrototypeOf(e)!==Object.prototype&&e.constructor)return e.constructor.name}}return t},n={regex:"ẹ̀rọ ìbáwọlé",email:"àdírẹ́sì ìmẹ́lì",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"àkókò ISO",date:"ọjọ́ ISO",time:"àkókò ISO",duration:"àkókò tó pé ISO",ipv4:"àdírẹ́sì IPv4",ipv6:"àdírẹ́sì IPv6",cidrv4:"àgbègbè IPv4",cidrv6:"àgbègbè IPv6",base64:"ọ̀rọ̀ tí a kọ́ ní base64",base64url:"ọ̀rọ̀ base64url",json_string:"ọ̀rọ̀ JSON",e164:"nọ́mbà E.164",jwt:"JWT",template_literal:"ẹ̀rọ ìbáwọlé"};return e=>{switch(e.code){case"invalid_type":return`Ìbáwọlé aṣìṣe: a ní láti fi ${e.expected}, àmọ̀ a rí ${o(e.input)}`;case"invalid_value":return e.values.length===1?`Ìbáwọlé aṣìṣe: a ní láti fi ${v(e.values[0])}`:`Àṣàyàn aṣìṣe: yan ọ̀kan lára ${c(e.values,"|")}`;case"too_big":{const t=e.inclusive?"<=":"<",r=i(e.origin);return r?`Tó pọ̀ jù: a ní láti jẹ́ pé ${e.origin??"iye"} ${r.verb} ${t}${e.maximum} ${r.unit}`:`Tó pọ̀ jù: a ní láti jẹ́ ${t}${e.maximum}`}case"too_small":{const t=e.inclusive?">=":">",r=i(e.origin);return r?`Kéré ju: a ní láti jẹ́ pé ${e.origin} ${r.verb} ${t}${e.minimum} ${r.unit}`:`Kéré ju: a ní láti jẹ́ ${t}${e.minimum}`}case"invalid_format":{const t=e;return t.format==="starts_with"?`Ọ̀rọ̀ aṣìṣe: gbọ́dọ̀ bẹ̀rẹ̀ pẹ̀lú "${t.prefix}"`:t.format==="ends_with"?`Ọ̀rọ̀ aṣìṣe: gbọ́dọ̀ parí pẹ̀lú "${t.suffix}"`:t.format==="includes"?`Ọ̀rọ̀ aṣìṣe: gbọ́dọ̀ ní "${t.includes}"`:t.format==="regex"?`Ọ̀rọ̀ aṣìṣe: gbọ́dọ̀ bá àpẹẹrẹ mu ${t.pattern}`:`Aṣìṣe: ${n[t.format]??e.format}`}case"not_multiple_of":return`Nọ́mbà aṣìṣe: gbọ́dọ̀ jẹ́ èyà pípín ti ${e.divisor}`;case"unrecognized_keys":return`Bọtìnì àìmọ̀: ${c(e.keys,", ")}`;case"invalid_key":return`Bọtìnì aṣìṣe nínú ${e.origin}`;case"invalid_union":return"Ìbáwọlé aṣìṣe";case"invalid_element":return`Iye aṣìṣe nínú ${e.origin}`;default:return"Ìbáwọlé aṣìṣe"}}};function Ks(){return{localeError:Ms()}}const St=Object.freeze(Object.defineProperty({__proto__:null,ar:ic,az:oc,be:lc,bg:dc,ca:fc,cs:vc,da:$c,de:yc,en:_t,eo:Sc,es:xc,fa:Oc,fi:Nc,fr:Dc,frCA:Tc,he:Ac,hu:Cc,id:Rc,is:Mc,it:Gc,ja:Bc,ka:qc,kh:Hc,km:kt,ko:es,lt:ns,mk:as,ms:us,nl:cs,no:ds,ota:fs,pl:$s,ps:vs,pt:ys,ru:_s,sl:Is,sv:js,ta:Us,th:ws,tr:Ds,ua:Ts,uk:It,ur:As,vi:Cs,yo:Ks,zhCN:Rs,zhTW:Fs},Symbol.toStringTag,{value:"Module"}));class re{constructor(i){this.counter=0,this.metadataRegistry=(i==null?void 0:i.metadata)??ie,this.target=(i==null?void 0:i.target)??"draft-2020-12",this.unrepresentable=(i==null?void 0:i.unrepresentable)??"throw",this.override=(i==null?void 0:i.override)??(()=>{}),this.io=(i==null?void 0:i.io)??"output",this.seen=new Map}process(i,o={path:[],schemaPath:[]}){var z,w,T;var n;const e=i._zod.def,t={guid:"uuid",url:"uri",datetime:"date-time",json_string:"json-string",regex:""},r=this.seen.get(i);if(r)return r.count++,o.schemaPath.includes(i)&&(r.cycle=o.path),r.schema;const u={schema:{},count:1,cycle:void 0,path:o.path};this.seen.set(i,u);const d=(w=(z=i._zod).toJSONSchema)==null?void 0:w.call(z);if(d)u.schema=d;else{const y={...o,schemaPath:[...o.schemaPath,i],path:o.path},A=i._zod.parent;if(A)u.ref=A,this.process(A,y),this.seen.get(A).isParent=!0;else{const m=u.schema;switch(e.type){case"string":{const l=m;l.type="string";const{minimum:g,maximum:f,format:_,patterns:b,contentEncoding:I}=i._zod.bag;if(typeof g=="number"&&(l.minLength=g),typeof f=="number"&&(l.maxLength=f),_&&(l.format=t[_]??_,l.format===""&&delete l.format),I&&(l.contentEncoding=I),b&&b.size>0){const x=[...b];x.length===1?l.pattern=x[0].source:x.length>1&&(u.schema.allOf=[...x.map(Z=>({...this.target==="draft-7"||this.target==="draft-4"||this.target==="openapi-3.0"?{type:"string"}:{},pattern:Z.source}))])}break}case"number":{const l=m,{minimum:g,maximum:f,format:_,multipleOf:b,exclusiveMaximum:I,exclusiveMinimum:x}=i._zod.bag;typeof _=="string"&&_.includes("int")?l.type="integer":l.type="number",typeof x=="number"&&(this.target==="draft-4"||this.target==="openapi-3.0"?(l.minimum=x,l.exclusiveMinimum=!0):l.exclusiveMinimum=x),typeof g=="number"&&(l.minimum=g,typeof x=="number"&&this.target!=="draft-4"&&(x>=g?delete l.minimum:delete l.exclusiveMinimum)),typeof I=="number"&&(this.target==="draft-4"||this.target==="openapi-3.0"?(l.maximum=I,l.exclusiveMaximum=!0):l.exclusiveMaximum=I),typeof f=="number"&&(l.maximum=f,typeof I=="number"&&this.target!=="draft-4"&&(I<=f?delete l.maximum:delete l.exclusiveMaximum)),typeof b=="number"&&(l.multipleOf=b);break}case"boolean":{const l=m;l.type="boolean";break}case"bigint":{if(this.unrepresentable==="throw")throw new Error("BigInt cannot be represented in JSON Schema");break}case"symbol":{if(this.unrepresentable==="throw")throw new Error("Symbols cannot be represented in JSON Schema");break}case"null":{this.target==="openapi-3.0"?(m.type="string",m.nullable=!0,m.enum=[null]):m.type="null";break}case"any":break;case"unknown":break;case"undefined":{if(this.unrepresentable==="throw")throw new Error("Undefined cannot be represented in JSON Schema");break}case"void":{if(this.unrepresentable==="throw")throw new Error("Void cannot be represented in JSON Schema");break}case"never":{m.not={};break}case"date":{if(this.unrepresentable==="throw")throw new Error("Date cannot be represented in JSON Schema");break}case"array":{const l=m,{minimum:g,maximum:f}=i._zod.bag;typeof g=="number"&&(l.minItems=g),typeof f=="number"&&(l.maxItems=f),l.type="array",l.items=this.process(e.element,{...y,path:[...y.path,"items"]});break}case"object":{const l=m;l.type="object",l.properties={};const g=e.shape;for(const b in g)l.properties[b]=this.process(g[b],{...y,path:[...y.path,"properties",b]});const f=new Set(Object.keys(g)),_=new Set([...f].filter(b=>{const I=e.shape[b]._zod;return this.io==="input"?I.optin===void 0:I.optout===void 0}));_.size>0&&(l.required=Array.from(_)),((T=e.catchall)==null?void 0:T._zod.def.type)==="never"?l.additionalProperties=!1:e.catchall?e.catchall&&(l.additionalProperties=this.process(e.catchall,{...y,path:[...y.path,"additionalProperties"]})):this.io==="output"&&(l.additionalProperties=!1);break}case"union":{const l=m,g=e.options.map((f,_)=>this.process(f,{...y,path:[...y.path,"anyOf",_]}));l.anyOf=g;break}case"intersection":{const l=m,g=this.process(e.left,{...y,path:[...y.path,"allOf",0]}),f=this.process(e.right,{...y,path:[...y.path,"allOf",1]}),_=I=>"allOf"in I&&Object.keys(I).length===1,b=[..._(g)?g.allOf:[g],..._(f)?f.allOf:[f]];l.allOf=b;break}case"tuple":{const l=m;l.type="array";const g=this.target==="draft-2020-12"?"prefixItems":"items",f=this.target==="draft-2020-12"||this.target==="openapi-3.0"?"items":"additionalItems",_=e.items.map((Z,H)=>this.process(Z,{...y,path:[...y.path,g,H]})),b=e.rest?this.process(e.rest,{...y,path:[...y.path,f,...this.target==="openapi-3.0"?[e.items.length]:[]]}):null;this.target==="draft-2020-12"?(l.prefixItems=_,b&&(l.items=b)):this.target==="openapi-3.0"?(l.items={anyOf:_},b&&l.items.anyOf.push(b),l.minItems=_.length,b||(l.maxItems=_.length)):(l.items=_,b&&(l.additionalItems=b));const{minimum:I,maximum:x}=i._zod.bag;typeof I=="number"&&(l.minItems=I),typeof x=="number"&&(l.maxItems=x);break}case"record":{const l=m;l.type="object",(this.target==="draft-7"||this.target==="draft-2020-12")&&(l.propertyNames=this.process(e.keyType,{...y,path:[...y.path,"propertyNames"]})),l.additionalProperties=this.process(e.valueType,{...y,path:[...y.path,"additionalProperties"]});break}case"map":{if(this.unrepresentable==="throw")throw new Error("Map cannot be represented in JSON Schema");break}case"set":{if(this.unrepresentable==="throw")throw new Error("Set cannot be represented in JSON Schema");break}case"enum":{const l=m,g=Lt(e.entries);g.every(f=>typeof f=="number")&&(l.type="number"),g.every(f=>typeof f=="string")&&(l.type="string"),l.enum=g;break}case"literal":{const l=m,g=[];for(const f of e.values)if(f===void 0){if(this.unrepresentable==="throw")throw new Error("Literal `undefined` cannot be represented in JSON Schema")}else if(typeof f=="bigint"){if(this.unrepresentable==="throw")throw new Error("BigInt literals cannot be represented in JSON Schema");g.push(Number(f))}else g.push(f);if(g.length!==0)if(g.length===1){const f=g[0];l.type=f===null?"null":typeof f,this.target==="draft-4"||this.target==="openapi-3.0"?l.enum=[f]:l.const=f}else g.every(f=>typeof f=="number")&&(l.type="number"),g.every(f=>typeof f=="string")&&(l.type="string"),g.every(f=>typeof f=="boolean")&&(l.type="string"),g.every(f=>f===null)&&(l.type="null"),l.enum=g;break}case"file":{const l=m,g={type:"string",format:"binary",contentEncoding:"binary"},{minimum:f,maximum:_,mime:b}=i._zod.bag;f!==void 0&&(g.minLength=f),_!==void 0&&(g.maxLength=_),b?b.length===1?(g.contentMediaType=b[0],Object.assign(l,g)):l.anyOf=b.map(I=>({...g,contentMediaType:I})):Object.assign(l,g);break}case"transform":{if(this.unrepresentable==="throw")throw new Error("Transforms cannot be represented in JSON Schema");break}case"nullable":{const l=this.process(e.innerType,y);this.target==="openapi-3.0"?(u.ref=e.innerType,m.nullable=!0):m.anyOf=[l,{type:"null"}];break}case"nonoptional":{this.process(e.innerType,y),u.ref=e.innerType;break}case"success":{const l=m;l.type="boolean";break}case"default":{this.process(e.innerType,y),u.ref=e.innerType,m.default=JSON.parse(JSON.stringify(e.defaultValue));break}case"prefault":{this.process(e.innerType,y),u.ref=e.innerType,this.io==="input"&&(m._prefault=JSON.parse(JSON.stringify(e.defaultValue)));break}case"catch":{this.process(e.innerType,y),u.ref=e.innerType;let l;try{l=e.catchValue(void 0)}catch{throw new Error("Dynamic catch values are not supported in JSON Schema")}m.default=l;break}case"nan":{if(this.unrepresentable==="throw")throw new Error("NaN cannot be represented in JSON Schema");break}case"template_literal":{const l=m,g=i._zod.pattern;if(!g)throw new Error("Pattern not found in template literal");l.type="string",l.pattern=g.source;break}case"pipe":{const l=this.io==="input"?e.in._zod.def.type==="transform"?e.out:e.in:e.out;this.process(l,y),u.ref=l;break}case"readonly":{this.process(e.innerType,y),u.ref=e.innerType,m.readOnly=!0;break}case"promise":{this.process(e.innerType,y),u.ref=e.innerType;break}case"optional":{this.process(e.innerType,y),u.ref=e.innerType;break}case"lazy":{const l=i._zod.innerType;this.process(l,y),u.ref=l;break}case"custom":{if(this.unrepresentable==="throw")throw new Error("Custom types cannot be represented in JSON Schema");break}case"function":{if(this.unrepresentable==="throw")throw new Error("Function types cannot be represented in JSON Schema");break}}}}const p=this.metadataRegistry.get(i);return p&&Object.assign(u.schema,p),this.io==="input"&&S(i)&&(delete u.schema.examples,delete u.schema.default),this.io==="input"&&u.schema._prefault&&((n=u.schema).default??(n.default=u.schema._prefault)),delete u.schema._prefault,this.seen.get(i).schema}emit(i,o){var N,z,w,T,y,A;const n={cycles:(o==null?void 0:o.cycles)??"ref",reused:(o==null?void 0:o.reused)??"inline",external:(o==null?void 0:o.external)??void 0},e=this.seen.get(i);if(!e)throw new Error("Unprocessed schema. This is a bug in Zod.");const t=m=>{var b;const l=this.target==="draft-2020-12"?"$defs":"definitions";if(n.external){const I=(b=n.external.registry.get(m[0]))==null?void 0:b.id,x=n.external.uri??(H=>H);if(I)return{ref:x(I)};const Z=m[1].defId??m[1].schema.id??`schema${this.counter++}`;return m[1].defId=Z,{defId:Z,ref:`${x("__shared")}#/${l}/${Z}`}}if(m[1]===e)return{ref:"#"};const f=`#/${l}/`,_=m[1].schema.id??`__schema${this.counter++}`;return{defId:_,ref:f+_}},r=m=>{if(m[1].schema.$ref)return;const l=m[1],{ref:g,defId:f}=t(m);l.def={...l.schema},f&&(l.defId=f);const _=l.schema;for(const b in _)delete _[b];_.$ref=g};if(n.cycles==="throw")for(const m of this.seen.entries()){const l=m[1];if(l.cycle)throw new Error(`Cycle detected: #/${(N=l.cycle)==null?void 0:N.join("/")}/<root>

Set the \`cycles\` parameter to \`"ref"\` to resolve cyclical schemas with defs.`)}for(const m of this.seen.entries()){const l=m[1];if(i===m[0]){r(m);continue}if(n.external){const f=(z=n.external.registry.get(m[0]))==null?void 0:z.id;if(i!==m[0]&&f){r(m);continue}}if((w=this.metadataRegistry.get(m[0]))==null?void 0:w.id){r(m);continue}if(l.cycle){r(m);continue}if(l.count>1&&n.reused==="ref"){r(m);continue}}const u=(m,l)=>{const g=this.seen.get(m),f=g.def??g.schema,_={...f};if(g.ref===null)return;const b=g.ref;if(g.ref=null,b){u(b,l);const I=this.seen.get(b).schema;I.$ref&&(l.target==="draft-7"||l.target==="draft-4"||l.target==="openapi-3.0")?(f.allOf=f.allOf??[],f.allOf.push(I)):(Object.assign(f,I),Object.assign(f,_))}g.isParent||this.override({zodSchema:m,jsonSchema:f,path:g.path??[]})};for(const m of[...this.seen.entries()].reverse())u(m[0],{target:this.target});const d={};if(this.target==="draft-2020-12"?d.$schema="https://json-schema.org/draft/2020-12/schema":this.target==="draft-7"?d.$schema="http://json-schema.org/draft-07/schema#":this.target==="draft-4"?d.$schema="http://json-schema.org/draft-04/schema#":this.target==="openapi-3.0"||console.warn(`Invalid target: ${this.target}`),(T=n.external)!=null&&T.uri){const m=(y=n.external.registry.get(i))==null?void 0:y.id;if(!m)throw new Error("Schema is missing an `id` property");d.$id=n.external.uri(m)}Object.assign(d,e.def);const p=((A=n.external)==null?void 0:A.defs)??{};for(const m of this.seen.entries()){const l=m[1];l.def&&l.defId&&(p[l.defId]=l.def)}n.external||Object.keys(p).length>0&&(this.target==="draft-2020-12"?d.$defs=p:d.definitions=p);try{return JSON.parse(JSON.stringify(d))}catch{throw new Error("Error converting schema to JSON.")}}}function jt(a,i){if(a instanceof $e){const n=new re(i),e={};for(const u of a._idmap.entries()){const[d,p]=u;n.process(p)}const t={},r={registry:a,uri:i==null?void 0:i.uri,defs:e};for(const u of a._idmap.entries()){const[d,p]=u;t[d]=n.emit(p,{...i,external:r})}if(Object.keys(e).length>0){const u=n.target==="draft-2020-12"?"$defs":"definitions";t.__shared={[u]:e}}return{schemas:t}}const o=new re(i);return o.process(a),o.emit(a,i)}function S(a,i){const o=i??{seen:new Set};if(o.seen.has(a))return!1;o.seen.add(a);const e=a._zod.def;switch(e.type){case"string":case"number":case"bigint":case"boolean":case"date":case"symbol":case"undefined":case"null":case"any":case"unknown":case"never":case"void":case"literal":case"enum":case"nan":case"file":case"template_literal":return!1;case"array":return S(e.element,o);case"object":{for(const t in e.shape)if(S(e.shape[t],o))return!0;return!1}case"union":{for(const t of e.options)if(S(t,o))return!0;return!1}case"intersection":return S(e.left,o)||S(e.right,o);case"tuple":{for(const t of e.items)if(S(t,o))return!0;return!!(e.rest&&S(e.rest,o))}case"record":return S(e.keyType,o)||S(e.valueType,o);case"map":return S(e.keyType,o)||S(e.valueType,o);case"set":return S(e.valueType,o);case"promise":case"optional":case"nonoptional":case"nullable":case"readonly":return S(e.innerType,o);case"lazy":return S(e.getter(),o);case"default":return S(e.innerType,o);case"prefault":return S(e.innerType,o);case"custom":return!1;case"transform":return!0;case"pipe":return S(e.in,o)||S(e.out,o);case"success":return!1;case"catch":return!1;case"function":return!1}throw new Error(`Unknown schema type: ${e.type}`)}const Gs=Object.freeze(Object.defineProperty({__proto__:null},Symbol.toStringTag,{value:"Module"})),Ws=Object.freeze(Object.defineProperty({__proto__:null,$ZodAny:Rt,$ZodArray:Jt,$ZodAsyncError:Ft,$ZodBase64:Mt,$ZodBase64URL:Kt,$ZodBigInt:Gt,$ZodBigIntFormat:Wt,$ZodBoolean:Bt,$ZodCIDRv4:Xt,$ZodCIDRv6:Vt,$ZodCUID:qt,$ZodCUID2:Yt,$ZodCatch:Ht,$ZodCheck:Qt,$ZodCheckBigIntFormat:er,$ZodCheckEndsWith:tr,$ZodCheckGreaterThan:rr,$ZodCheckIncludes:nr,$ZodCheckLengthEquals:ir,$ZodCheckLessThan:ar,$ZodCheckLowerCase:or,$ZodCheckMaxLength:ur,$ZodCheckMaxSize:lr,$ZodCheckMimeType:cr,$ZodCheckMinLength:sr,$ZodCheckMinSize:dr,$ZodCheckMultipleOf:mr,$ZodCheckNumberFormat:fr,$ZodCheckOverwrite:gr,$ZodCheckProperty:vr,$ZodCheckRegex:pr,$ZodCheckSizeEquals:$r,$ZodCheckStartsWith:br,$ZodCheckStringFormat:yr,$ZodCheckUpperCase:hr,$ZodCodec:_r,$ZodCustom:kr,$ZodCustomStringFormat:Ir,$ZodDate:Sr,$ZodDefault:jr,$ZodDiscriminatedUnion:xr,$ZodE164:Ur,$ZodEmail:Or,$ZodEmoji:wr,$ZodEncodeError:Nr,$ZodEnum:zr,$ZodError:Dr,$ZodFile:Pr,$ZodFunction:Tr,$ZodGUID:Er,$ZodIPv4:Ar,$ZodIPv6:Zr,$ZodISODate:Cr,$ZodISODateTime:Lr,$ZodISODuration:Rr,$ZodISOTime:Jr,$ZodIntersection:Fr,$ZodJWT:Mr,$ZodKSUID:Kr,$ZodLazy:Gr,$ZodLiteral:Wr,$ZodMap:Br,$ZodNaN:Xr,$ZodNanoID:Vr,$ZodNever:qr,$ZodNonOptional:Yr,$ZodNull:Hr,$ZodNullable:Qr,$ZodNumber:en,$ZodNumberFormat:tn,$ZodObject:rn,$ZodObjectJIT:nn,$ZodOptional:an,$ZodPipe:on,$ZodPrefault:un,$ZodPromise:ln,$ZodReadonly:cn,$ZodRealError:sn,$ZodRecord:dn,$ZodRegistry:$e,$ZodSet:mn,$ZodString:fn,$ZodStringFormat:gn,$ZodSuccess:vn,$ZodSymbol:pn,$ZodTemplateLiteral:$n,$ZodTransform:bn,$ZodTuple:yn,$ZodType:hn,$ZodULID:_n,$ZodURL:kn,$ZodUUID:In,$ZodUndefined:Sn,$ZodUnion:jn,$ZodUnknown:xn,$ZodVoid:Un,$ZodXID:On,$brand:be,$constructor:wn,$input:ye,$output:he,Doc:Nn,JSONSchema:Gs,JSONSchemaGenerator:re,NEVER:_e,TimePrecision:ke,_any:zn,_array:Dn,_base64:Pn,_base64url:Tn,_bigint:En,_boolean:An,_catch:Zn,_check:Cn,_cidrv4:Ln,_cidrv6:Rn,_coercedBigint:Ie,_coercedBoolean:Se,_coercedDate:je,_coercedNumber:xe,_coercedString:Ue,_cuid:Jn,_cuid2:Fn,_custom:Mn,_date:Kn,_decode:Gn,_decodeAsync:Wn,_default:Bn,_discriminatedUnion:Xn,_e164:Vn,_email:qn,_emoji:Yn,_encode:Hn,_encodeAsync:Qn,_endsWith:Oe,_enum:ei,_file:ti,_float32:ri,_float64:ni,_gt:we,_gte:ee,_guid:ii,_includes:Ne,_int:ai,_int32:oi,_int64:ui,_intersection:li,_ipv4:ci,_ipv6:si,_isoDate:di,_isoDateTime:mi,_isoDuration:fi,_isoTime:gi,_jwt:vi,_ksuid:pi,_lazy:$i,_length:ze,_literal:bi,_lowercase:De,_lt:Pe,_lte:te,_map:yi,_max:te,_maxLength:Te,_maxSize:Ee,_mime:Ae,_min:ee,_minLength:Ze,_minSize:Ce,_multipleOf:Le,_nan:hi,_nanoid:_i,_nativeEnum:ki,_negative:Re,_never:Ii,_nonnegative:Je,_nonoptional:Si,_nonpositive:Fe,_normalize:Me,_null:ji,_nullable:xi,_number:Ui,_optional:Oi,_overwrite:Ke,_parse:wi,_parseAsync:Ni,_pipe:zi,_positive:Ge,_promise:Di,_property:We,_readonly:Pi,_record:Ti,_refine:Ei,_regex:Be,_safeDecode:Ai,_safeDecodeAsync:Zi,_safeEncode:Ci,_safeEncodeAsync:Li,_safeParse:Ri,_safeParseAsync:Ji,_set:Fi,_size:Xe,_startsWith:Ve,_string:Mi,_stringFormat:Ki,_stringbool:Gi,_success:Wi,_superRefine:Bi,_symbol:Xi,_templateLiteral:Vi,_toLowerCase:qe,_toUpperCase:Ye,_transform:qi,_trim:He,_tuple:Yi,_uint32:Hi,_uint64:Qi,_ulid:ea,_undefined:ta,_union:ra,_unknown:na,_uppercase:Qe,_url:ia,_uuid:aa,_uuidv4:oa,_uuidv6:ua,_uuidv7:la,_void:ca,_xid:sa,clone:et,config:ae,decode:da,decodeAsync:ma,encode:fa,encodeAsync:ga,flattenError:tt,formatError:rt,globalConfig:va,globalRegistry:ie,isValidBase64:pa,isValidBase64URL:$a,isValidJWT:ba,locales:St,parse:ya,parseAsync:ha,prettifyError:nt,regexes:it,registry:at,safeDecode:_a,safeDecodeAsync:ka,safeEncode:Ia,safeEncodeAsync:Sa,safeParse:ja,safeParseAsync:xa,toDotPath:Ua,toJSONSchema:jt,treeifyError:ot,util:ut,version:Oa},Symbol.toStringTag,{value:"Module"}));function Bs(a){return Ue(lt,a)}function Xs(a){return xe(ct,a)}function Vs(a){return Se(st,a)}function qs(a){return Ie(dt,a)}function Ys(a){return je(mt,a)}const Hs=Object.freeze(Object.defineProperty({__proto__:null,bigint:qs,boolean:Vs,date:Ys,number:Xs,string:Bs},Symbol.toStringTag,{value:"Module"}));ae(_t());const K=Object.freeze(Object.defineProperty({__proto__:null,$brand:be,$input:ye,$output:he,NEVER:_e,TimePrecision:ke,ZodAny:wa,ZodArray:Na,ZodBase64:za,ZodBase64URL:Da,ZodBigInt:dt,ZodBigIntFormat:Pa,ZodBoolean:st,ZodCIDRv4:Ta,ZodCIDRv6:Ea,ZodCUID:Aa,ZodCUID2:Za,ZodCatch:Ca,ZodCodec:La,ZodCustom:Ra,ZodCustomStringFormat:Ja,ZodDate:mt,ZodDefault:Fa,ZodDiscriminatedUnion:Ma,ZodE164:Ka,ZodEmail:Ga,ZodEmoji:Wa,ZodEnum:Ba,ZodError:Xa,ZodFile:Va,get ZodFirstPartyTypeKind(){return qa},ZodFunction:Ya,ZodGUID:Ha,ZodIPv4:Qa,ZodIPv6:eo,ZodISODate:to,ZodISODateTime:ro,ZodISODuration:no,ZodISOTime:io,ZodIntersection:ao,ZodIssueCode:oo,ZodJWT:uo,ZodKSUID:lo,ZodLazy:co,ZodLiteral:so,ZodMap:mo,ZodNaN:fo,ZodNanoID:go,ZodNever:vo,ZodNonOptional:po,ZodNull:$o,ZodNullable:bo,ZodNumber:ct,ZodNumberFormat:yo,ZodObject:ho,ZodOptional:_o,ZodPipe:ko,ZodPrefault:Io,ZodPromise:So,ZodReadonly:jo,ZodRealError:xo,ZodRecord:Uo,ZodSet:Oo,ZodString:lt,ZodStringFormat:wo,ZodSuccess:No,ZodSymbol:zo,ZodTemplateLiteral:Do,ZodTransform:Po,ZodTuple:To,ZodType:Eo,ZodULID:Ao,ZodURL:Zo,ZodUUID:Co,ZodUndefined:Lo,ZodUnion:Ro,ZodUnknown:Jo,ZodVoid:Fo,ZodXID:Mo,_ZodString:Ko,_default:Go,_function:ce,any:P,array:L,base64:Wo,base64url:Bo,bigint:Xo,boolean:D,catch:Vo,check:qo,cidrv4:Yo,cidrv6:Ho,clone:et,codec:Qo,coerce:Hs,config:ae,core:Ws,cuid:eu,cuid2:tu,custom:ru,date:ft,decode:nu,decodeAsync:iu,discriminatedUnion:au,e164:ou,email:uu,emoji:lu,encode:cu,encodeAsync:su,endsWith:Oe,enum:F,file:du,flattenError:tt,float32:mu,float64:fu,formatError:rt,function:ce,getErrorMap:gu,globalRegistry:ie,gt:we,gte:ee,guid:vu,hash:pu,hex:$u,hostname:bu,httpUrl:yu,includes:Ne,instanceof:hu,int:_u,int32:ku,int64:Iu,intersection:Su,ipv4:ju,ipv6:xu,iso:Uu,json:Ou,jwt:wu,keyof:Nu,ksuid:zu,lazy:Du,length:ze,literal:Pu,locales:St,looseObject:Tu,lowercase:De,lt:Pe,lte:te,map:Eu,maxLength:Te,maxSize:Ee,mime:Ae,minLength:Ze,minSize:Ce,multipleOf:Le,nan:Au,nanoid:Zu,nativeEnum:Cu,negative:Re,never:Lu,nonnegative:Je,nonoptional:Ru,nonpositive:Fe,normalize:Me,null:Ju,nullable:U,nullish:Fu,number:h,object:k,optional:Mu,overwrite:Ke,parse:Ku,parseAsync:Gu,partialRecord:Wu,pipe:Bu,positive:Ge,prefault:Xu,preprocess:Vu,prettifyError:nt,promise:qu,property:We,readonly:Yu,record:C,refine:Hu,regex:Be,regexes:it,registry:at,safeDecode:Qu,safeDecodeAsync:el,safeEncode:tl,safeEncodeAsync:rl,safeParse:nl,safeParseAsync:il,set:al,setErrorMap:ol,size:Xe,startsWith:Ve,strictObject:ul,string:$,stringFormat:ll,stringbool:cl,success:sl,superRefine:dl,symbol:ml,templateLiteral:fl,toJSONSchema:jt,toLowerCase:qe,toUpperCase:Ye,transform:gl,treeifyError:ot,trim:He,tuple:vl,uint32:pl,uint64:$l,ulid:bl,undefined:yl,union:hl,unknown:_l,uppercase:Qe,url:kl,util:ut,uuid:Il,uuidv4:Sl,uuidv6:jl,uuidv7:xl,void:Ul,xid:Ol},Symbol.toStringTag,{value:"Module"})),q=F(["knowledge_base","mineru","s3","system","custom"]);F(["enabled","disabled"]);const oe=k({id:h(),type:q,name:$(),value:U(P()),created_at:ft().or(h())});k({type:q,name:$(),value:U(P())});k({type:q.optional(),name:$().optional(),value:U(P()).optional()});k({type:q.optional(),skip:h().min(0).default(0),limit:h().min(1).max(1e3).default(100)});const xt=k({success:D().default(!0),message:$().default("操作成功")});k({data:L(oe),total:h(),page:U(h()),pageSize:U(h())});xt.extend({data:oe});xt.extend({data:oe});const O=F(["waiting","running","success","failed","timeout","cancelled"]),V=F(["parse","chunk","import"]),Qs=k({filename:$(),mime_type:$(),size:h(),path:$()}),ed=k({id:h(),phase:V,phases:U(L(V)),status:O,errorMessage:U($()),config:U(P()),results:U(C(V,k({input:L(Qs),output:U(L($()))}))),created_at:h(),updatedAt:U(h())}),Ut=k({id:h(),name:$(),created_at:h(),updatedAt:U(h()),jobId:h(),job:U(ed)});k({success:D().default(!0),message:$().default("操作成功")});k({data:k({items:L(Ut),total:h(),page:h(),pageSize:h()})});k({success:D().default(!0),message:$().default("操作成功"),data:k({id:h()})});k({data:Ut});k({data:C($(),P()),size:h(),modified:h()});k({success:D().default(!0),message:$().default("操作成功"),data:k({total:h(),statusCounts:C($(),h())})});k({success:D().default(!1),message:$(),errorCode:U($()),details:U(P())});k({mediaDir:$(),cacheDir:$(),databasePath:$(),status:$(),version:$(),startTime:$(),environment:$(),pid:h(),uptime:h(),memory:k({rss:h(),vms:h()}),platform:$(),pythonVersion:$()});k({status:$(),timestamp:$(),services:k({api:D(),database:D(),worker:D()})});k({cpuUsage:h().optional(),diskUsage:C($(),P()).optional(),networkStats:k({bytesReceived:h(),bytesSent:h()}).optional()});k({config:C($(),P()).describe("任务配置"),filePath:$().min(1,"文件路径不能为空")});k({config:C($(),P()).optional(),filePath:$().optional()});k({page:h().min(1).default(1),pageSize:h().min(1).max(100).default(20),name:$().optional(),phase:V.optional(),status:O.optional(),sortBy:$().default("created_at"),sortOrder:F(["asc","desc"]).default("desc")});k({success:D().default(!0),message:$().default("操作成功"),data:k({path:$().describe("上传路径信息")})});K.object({page:K.number().min(1).default(1),pageSize:K.number().min(1).max(100).default(20),sortBy:K.string().default("created_at"),sortOrder:K.enum(["asc","desc"]).default("desc")});var Y="Popover",[Ot]=zl(Y,[gt]),X=gt(),[td,E]=Ot(Y),wt=a=>{const{__scopePopover:i,children:o,open:n,defaultOpen:e,onOpenChange:t,modal:r=!1}=a,u=X(i),d=j.useRef(null),[p,N]=j.useState(!1),[z,w]=wl({prop:n,defaultProp:e??!1,onChange:t,caller:Y});return s.jsx(Nl,{...u,children:s.jsx(td,{scope:i,contentId:Dl(),triggerRef:d,open:z,onOpenChange:w,onOpenToggle:j.useCallback(()=>w(T=>!T),[w]),hasCustomAnchor:p,onCustomAnchorAdd:j.useCallback(()=>N(!0),[]),onCustomAnchorRemove:j.useCallback(()=>N(!1),[]),modal:r,children:o})})};wt.displayName=Y;var Nt="PopoverAnchor",rd=j.forwardRef((a,i)=>{const{__scopePopover:o,...n}=a,e=E(Nt,o),t=X(o),{onCustomAnchorAdd:r,onCustomAnchorRemove:u}=e;return j.useEffect(()=>(r(),()=>u()),[r,u]),s.jsx($t,{...t,...n,ref:i})});rd.displayName=Nt;var zt="PopoverTrigger",Dt=j.forwardRef((a,i)=>{const{__scopePopover:o,...n}=a,e=E(zt,o),t=X(o),r=vt(i,e.triggerRef),u=s.jsx(pt.button,{type:"button","aria-haspopup":"dialog","aria-expanded":e.open,"aria-controls":e.contentId,"data-state":Zt(e.open),...n,ref:r,onClick:W(a.onClick,e.onOpenToggle)});return e.hasCustomAnchor?u:s.jsx($t,{asChild:!0,...t,children:u})});Dt.displayName=zt;var ue="PopoverPortal",[nd,id]=Ot(ue,{forceMount:void 0}),Pt=a=>{const{__scopePopover:i,forceMount:o,children:n,container:e}=a,t=E(ue,i);return s.jsx(nd,{scope:i,forceMount:o,children:s.jsx(bt,{present:o||t.open,children:s.jsx(Pl,{asChild:!0,container:e,children:n})})})};Pt.displayName=ue;var J="PopoverContent",Tt=j.forwardRef((a,i)=>{const o=id(J,a.__scopePopover),{forceMount:n=o.forceMount,...e}=a,t=E(J,a.__scopePopover);return s.jsx(bt,{present:n||t.open,children:t.modal?s.jsx(od,{...e,ref:i}):s.jsx(ud,{...e,ref:i})})});Tt.displayName=J;var ad=Al("PopoverContent.RemoveScroll"),od=j.forwardRef((a,i)=>{const o=E(J,a.__scopePopover),n=j.useRef(null),e=vt(i,n),t=j.useRef(!1);return j.useEffect(()=>{const r=n.current;if(r)return Tl(r)},[]),s.jsx(El,{as:ad,allowPinchZoom:!0,children:s.jsx(Et,{...a,ref:e,trapFocus:o.open,disableOutsidePointerEvents:!0,onCloseAutoFocus:W(a.onCloseAutoFocus,r=>{var u;r.preventDefault(),t.current||(u=o.triggerRef.current)==null||u.focus()}),onPointerDownOutside:W(a.onPointerDownOutside,r=>{const u=r.detail.originalEvent,d=u.button===0&&u.ctrlKey===!0,p=u.button===2||d;t.current=p},{checkForDefaultPrevented:!1}),onFocusOutside:W(a.onFocusOutside,r=>r.preventDefault(),{checkForDefaultPrevented:!1})})})}),ud=j.forwardRef((a,i)=>{const o=E(J,a.__scopePopover),n=j.useRef(!1),e=j.useRef(!1);return s.jsx(Et,{...a,ref:i,trapFocus:!1,disableOutsidePointerEvents:!1,onCloseAutoFocus:t=>{var r,u;(r=a.onCloseAutoFocus)==null||r.call(a,t),t.defaultPrevented||(n.current||(u=o.triggerRef.current)==null||u.focus(),t.preventDefault()),n.current=!1,e.current=!1},onInteractOutside:t=>{var d,p;(d=a.onInteractOutside)==null||d.call(a,t),t.defaultPrevented||(n.current=!0,t.detail.originalEvent.type==="pointerdown"&&(e.current=!0));const r=t.target;((p=o.triggerRef.current)==null?void 0:p.contains(r))&&t.preventDefault(),t.detail.originalEvent.type==="focusin"&&e.current&&t.preventDefault()}})}),Et=j.forwardRef((a,i)=>{const{__scopePopover:o,trapFocus:n,onOpenAutoFocus:e,onCloseAutoFocus:t,disableOutsidePointerEvents:r,onEscapeKeyDown:u,onPointerDownOutside:d,onFocusOutside:p,onInteractOutside:N,...z}=a,w=E(J,o),T=X(o);return Zl(),s.jsx(Cl,{asChild:!0,loop:!0,trapped:n,onMountAutoFocus:e,onUnmountAutoFocus:t,children:s.jsx(Ll,{asChild:!0,disableOutsidePointerEvents:r,onInteractOutside:N,onEscapeKeyDown:u,onPointerDownOutside:d,onFocusOutside:p,onDismiss:()=>w.onOpenChange(!1),children:s.jsx(Rl,{"data-state":Zt(w.open),role:"dialog",id:w.contentId,...T,...z,ref:i,style:{...z.style,"--radix-popover-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-popover-content-available-width":"var(--radix-popper-available-width)","--radix-popover-content-available-height":"var(--radix-popper-available-height)","--radix-popover-trigger-width":"var(--radix-popper-anchor-width)","--radix-popover-trigger-height":"var(--radix-popper-anchor-height)"}})})})}),At="PopoverClose",ld=j.forwardRef((a,i)=>{const{__scopePopover:o,...n}=a,e=E(At,o);return s.jsx(pt.button,{type:"button",...n,ref:i,onClick:W(a.onClick,()=>e.onOpenChange(!1))})});ld.displayName=At;var cd="PopoverArrow",sd=j.forwardRef((a,i)=>{const{__scopePopover:o,...n}=a,e=X(o);return s.jsx(Jl,{...e,...n,ref:i})});sd.displayName=cd;function Zt(a){return a?"open":"closed"}var dd=wt,md=Dt,fd=Pt,gd=Tt;function vd({...a}){return s.jsx(dd,{"data-slot":"popover",...a})}function pd({...a}){return s.jsx(md,{"data-slot":"popover-trigger",...a})}function $d({className:a,align:i="center",sideOffset:o=4,...n}){return s.jsx(fd,{children:s.jsx(gd,{"data-slot":"popover-content",align:i,sideOffset:o,className:R("bg-popover text-popover-foreground data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 z-50 w-72 origin-(--radix-popover-content-transform-origin) rounded-md border p-4 shadow-md outline-hidden",a),...n})})}const Ct=[{key:"parse",labelKey:"tasks.detail.phases.parse.label",descriptionKey:"tasks.detail.phases.parse.description",icon:s.jsx(Ml,{}),order:1},{key:"chunk",labelKey:"tasks.detail.phases.chunk.label",descriptionKey:"tasks.detail.phases.chunk.description",icon:s.jsx(Yl,{}),order:2},{key:"import",labelKey:"tasks.detail.phases.import.label",descriptionKey:"tasks.detail.phases.import.description",icon:s.jsx(Kl,{}),order:3}],bd=Ct.reduce((a,i)=>(a[i.key]=i,a),{}),yd=[...Ct].sort((a,i)=>a.order-i.order).map(a=>a.key),hd={[O.enum.success]:"text-green-500",[O.enum.running]:"text-blue-500",[O.enum.failed]:"text-red-500",[O.enum.waiting]:"text-gray-500",[O.enum.cancelled]:"text-yellow-500",[O.enum.timeout]:"text-yellow-500",pending:"text-gray-500"},fe={success:"bg-green-500 border-green-500 text-white",failed:"bg-red-500 border-red-500 text-white",running:"bg-blue-500 border-blue-500 text-white animate-pulse",waiting:"bg-gray-300 border-gray-300 text-gray-600",timeout:"bg-orange-500 border-orange-500 text-white",cancelled:"bg-gray-500 border-gray-500 text-white",pending:"bg-gray-300 border-gray-300 text-gray-600"},_d={[O.enum.success]:s.jsx(Bl,{}),[O.enum.failed]:s.jsx(yt,{}),[O.enum.running]:s.jsx(ht,{className:"animate-spin"}),[O.enum.waiting]:s.jsx(Wl,{}),[O.enum.timeout]:s.jsx(tc,{}),[O.enum.cancelled]:s.jsx(Vl,{}),pending:s.jsx(Ql,{})},ge={success:"#22c55e",failed:"#ef4444",running:"#3b82f6",waiting:"#d1d5db",timeout:"#f97316",cancelled:"#6b7280",pending:"#d1d5db"};function ne(a){return Array.from(new Set(a))}function Q(a,i){return ne([...a,i])}function kd(a){if(!a||typeof a!="object")return[];const i=a,o=[];return"mineru"in i&&o.push("parse"),i.chunk&&typeof i.chunk=="object"&&Object.keys(i.chunk).length>0&&o.push("chunk"),Array.isArray(i.knowledgeBases)&&i.knowledgeBases.length>0&&o.push("import"),o}function Id(a){const i=Array.isArray(a.phases)?a.phases:[];if(i.length>0)return Q(ne(i),a.phase);const o=kd(a.config);return o.length>0?Q(ne(o),a.phase):Q(yd,a.phase)}function ve(a){const i=Object.prototype.hasOwnProperty.call(ge,a)?a:"waiting";return ge[i]}function Sd({jobStatus:a,phaseIndex:i,currentPhaseIndex:o,hasValidCurrentIndex:n,completionTimestamp:e,errorMessage:t}){const r=n&&i<o,u=n&&i===o?!0:!n&&i===0;switch(a){case"waiting":return n?r?{status:"success",completedAt:e}:u?{status:"waiting",isActive:!0}:{status:"waiting"}:{status:"waiting",isActive:!0};case"success":return{status:"success",completedAt:e};case"failed":return r?{status:"success",completedAt:e}:u?{status:"failed",isActive:!0,errorMessage:t}:{status:"waiting"};case"running":return r?{status:"success",completedAt:e}:u?{status:"running",isActive:!0}:{status:"waiting"};case"timeout":case"cancelled":return r?{status:"success",completedAt:e}:u?{status:a,isActive:!0,errorMessage:t}:{status:"waiting"};default:return i===0?{status:a,isActive:a==="waiting"}:{status:"waiting"}}}function jd(a){const i=a.job;if(!i)return[];const o=Id(i);if(o.length===0)return[];const n=i.status,e=o.indexOf(i.phase),t=e>=0,r=i.updatedAt??a.updatedAt??i.created_at??a.created_at??void 0,u=i.errorMessage||void 0;return o.map((d,p)=>{const N=Sd({jobStatus:n,phaseIndex:p,currentPhaseIndex:e,hasValidCurrentIndex:t,completionTimestamp:r,errorMessage:u});return{key:d,...N}})}function xd({phase:a,isActive:i,onRetry:o}){const{t:n,i18n:e}=pe(),t=e.resolvedLanguage??e.language??"en-US",r=bd[a.key],u=r!=null&&r.labelKey?n(r.labelKey):a.key,d=r!=null&&r.descriptionKey?n(r.descriptionKey):void 0,p=Object.prototype.hasOwnProperty.call(fe,a.status)?a.status:"waiting",N=fe[p],z=_d[p]||"";return s.jsxs(vd,{children:[s.jsx(pd,{asChild:!0,children:s.jsx("div",{className:R("relative w-2 h-2 rounded-full border-2 cursor-pointer transition-all duration-200",N,i&&a.status==="running"&&"ring-2 ring-blue-400 ring-offset-1 scale-110",i&&a.status==="failed"&&"ring-2 ring-red-400 ring-offset-1",a.status==="failed"&&"hover:scale-110",a.status==="running"&&"shadow-lg")})}),s.jsx($d,{className:"w-72",children:s.jsxs("div",{className:"space-y-3",children:[s.jsxs("div",{className:"flex items-center gap-2",children:[s.jsx("div",{className:R("w-4 h-4 rounded-full flex items-center justify-center text-xs",hd[p]),children:z}),s.jsx("div",{className:"flex gap-2 justify-center items-center",children:s.jsx("div",{className:"font-medium text-sm",children:u})})]}),d&&s.jsx("div",{className:"text-xs text-gray-600",children:d}),a.status==="success"&&a.completedAt&&s.jsxs("div",{className:"text-xs text-green-600 bg-green-50 p-2 rounded",children:[s.jsxs("div",{className:"font-medium",children:["✓",n("tasks.detail.phaseBar.completed")]}),s.jsx("div",{className:"text-gray-500 mt-1",children:new Date(a.completedAt).toLocaleString(t)})]}),a.status==="running"&&s.jsx("div",{className:"text-xs text-blue-600 bg-blue-50 p-2 rounded",children:s.jsxs("div",{className:"font-medium flex items-center gap-1",children:[s.jsx("div",{className:"w-2 h-2 bg-blue-500 rounded-full animate-pulse"}),n("tasks.detail.phaseBar.running")]})}),a.status==="failed"&&s.jsxs("div",{className:"space-y-2",children:[s.jsx(Gl,{content:a.errorMessage??n("tasks.detail.phaseBar.defaultError"),className:"text-xs"}),o&&s.jsxs(Fl,{size:"sm",variant:"outline",className:"w-full text-xs",onClick:()=>o(a.key),children:[s.jsx(ht,{className:"w-3 h-3 mr-1"}),n("tasks.detail.phaseBar.retryPhase")]})]}),(a.status==="timeout"||a.status==="cancelled")&&s.jsx("div",{className:"text-xs text-orange-600 bg-orange-50 p-2 rounded",children:a.errorMessage&&s.jsx("div",{className:"text-gray-600 mt-1",children:a.errorMessage})})]})})]})}function Ud({fromStatus:a,toStatus:i,isActive:o}){const n=ve(a),e=ve(i),t=n===e?n:`linear-gradient(90deg, ${n} 0%, ${e} 100%)`;return s.jsx("div",{className:"h-1 w-3 flex items-center",children:s.jsx("div",{className:R("h-0.5 w-full transition-all duration-300",o?"opacity-100":"opacity-70"),style:{background:t}})})}function Ed({task:a,onRetry:i,className:o}){const{t:n}=pe(),e=le.useMemo(()=>jd(a),[a]);return e.length===0?s.jsxs("div",{className:R("flex items-center text-gray-500 text-sm",o),children:[s.jsx(yt,{className:"w-4 h-4 mr-2"}),n("tasks.detail.phaseBar.noPhaseInfo")]}):s.jsx("div",{className:R("flex items-center py-2",o),children:e.map((t,r)=>{const u=t.isActive||!1,d=e[r+1],p=u||!!(d!=null&&d.isActive);return s.jsxs(le.Fragment,{children:[s.jsx(xd,{phase:t,isActive:u,onRetry:i}),r<e.length-1&&d&&s.jsx(Ud,{fromStatus:t.status,toStatus:d.status,isActive:p})]},t.key)})})}export{Yl as B,hd as I,Ed as P,_d as S,Td as a,Ct as b,V as p,O as s};
